@@ -123,63 +123,57 @@ calc_adipot(size_t gridsize, size_t nlevel, const Varray<double> &pressure, cons
     }
 }
 
-void *
-Adisit(void *process)
-{
-  int thoID = -1, saoID = -1;
-  char varname[CDI_MAX_NAME], stdname[CDI_MAX_NAME];
+int getCode(const int vlistID1, const int varID, const std::string& cname) {
+  char varname[CDI_MAX_NAME];
+  char stdname[CDI_MAX_NAME];
 
-  cdo_initialize(process);
-
-  const auto ADISIT = cdo_operator_add("adisit", 0, 0, "");
-  const auto ADIPOT = cdo_operator_add("adipot", 0, 0, "");
-
-  const auto operatorID = cdo_operator_id();
-
-  const auto pin = (cdo_operator_argc() == 1) ? parameter_to_double(cdo_operator_argv(0)) : -1.0;
-
-  const auto streamID1 = cdo_open_read(0);
-  const auto vlistID1 = cdo_stream_inq_vlist(streamID1);
-
-  const auto nvars = vlistNvars(vlistID1);
-
-  for (int varID = 0; varID < nvars; varID++)
+  int code = vlistInqVarCode(vlistID1, varID);
+  if (code <= 0)
     {
-      auto code = vlistInqVarCode(vlistID1, varID);
-      if (code <= 0)
-        {
-          vlistInqVarName(vlistID1, varID, varname);
-          cstr_to_lower_case(varname);
+      vlistInqVarName(vlistID1, varID, varname);
+      cstr_to_lower_case(varname);
 
-          int length = CDI_MAX_NAME;
-          cdiInqKeyString(vlistID1, varID, CDI_KEY_STDNAME, stdname, &length);
-          cstr_to_lower_case(stdname);
+      int length = CDI_MAX_NAME;
+      cdiInqKeyString(vlistID1, varID, CDI_KEY_STDNAME, stdname, &length);
+      cstr_to_lower_case(stdname);
 
-          if (cdo_cmpstr(varname, "s") || cdo_cmpstr(stdname, "sea_water_salinity"))
-            code = 5;
-          else if (cdo_cmpstr(varname, "t"))
-            code = 2;
+      if (cdo_cmpstr(varname, "s") || cdo_cmpstr(stdname, "sea_water_salinity")) {
+        code = 5;
+      } else if (cdo_cmpstr(varname, "t")) {
+        code = 2;
+      }
 
-          const char *cname = (operatorID == ADISIT) ? "sea_water_potential_temperature" : "sea_water_temperature";
-          if (cdo_cmpstr(stdname, cname)) code = 2;
-        }
-
-      if (code == 2 || (code == 20 && operatorID == ADIPOT))
-        thoID = varID;
-      else if (code == 5)
-        saoID = varID;
+      if (cdo_cmpstr(stdname, cname.c_str())) {
+        code = 2;
+      }
     }
 
-  if (saoID == -1) cdo_abort("Sea water salinity not found!");
-  if (thoID == -1) cdo_abort("%s temperature not found!", (operatorID == ADISIT) ? "Potential" : "Insitu");
+    return code;
+}
+
+struct IOSettings {
+  CdoStreamID streamID2;
+  const int vlistID2;
+  const size_t gridsize;
+  const int nlevels;
+  const int taxisID1;
+  const int taxisID2;
+  const int tisID2;
+  const int saoID2;
+};
+
+IOSettings configureOutput(std::function<void(const int, const int)> outputSettingFuc, const int vlistID1, const int thoID, const int saoID, char* units, FieldVector& tho, FieldVector& sao, FieldVector& tis, Varray<double>& pressure) {
+  const double pin = (cdo_operator_argc() == 1) ? parameter_to_double(cdo_operator_argv(0)) : -1.0;
+
 
-  char units[CDI_MAX_NAME] = { 0 };
   int length = CDI_MAX_NAME;
   cdiInqKeyString(vlistID1, thoID, CDI_KEY_UNITS, units, &length);
-  if (length == 0) strcpy(units, "Celcius");
+  if (length == 0) {
+    strcpy(units, "Celcius");
+  }
 
-  const auto gridID = vlistGrid(vlistID1, 0);
-  const auto gridsize = vlist_check_gridsize(vlistID1);
+  const int gridID = vlistGrid(vlistID1, 0);
+  const size_t gridsize = vlist_check_gridsize(vlistID1);
 
   auto zaxisID = vlistInqVarZaxis(vlistID1, saoID);
   const auto nlevels1 = zaxisInqSize(zaxisID);
@@ -189,7 +183,7 @@ Adisit(void *process)
   if (nlevels1 != nlevels2) cdo_abort("temperature and salinity have different number of levels!");
   const auto nlevels = nlevels1;
 
-  Varray<double> pressure(nlevels);
+  pressure.resize(nlevels);
   cdo_zaxis_inq_levels(zaxisID, pressure.data());
 
   if (pin >= 0)
@@ -203,7 +197,9 @@ Adisit(void *process)
       for (int i = 0; i < nlevels; ++i) cdo_print("%5d  %g", i + 1, pressure[i]);
     }
 
-  FieldVector tho(nlevels), sao(nlevels), tis(nlevels);
+  tho.resize(nlevels, Field{});
+  sao.resize(nlevels, Field{});
+  tis.resize(nlevels, Field{});
   for (int levelID = 0; levelID < nlevels; ++levelID)
     {
       tho[levelID].resize(gridsize);
@@ -218,24 +214,12 @@ Adisit(void *process)
   if (vlistInqVarDatatype(vlistID1, thoID) == CDI_DATATYPE_FLT64 && vlistInqVarDatatype(vlistID1, saoID) == CDI_DATATYPE_FLT64)
     datatype = CDI_DATATYPE_FLT64;
 
-  const auto vlistID2 = vlistCreate();
+  const int vlistID2 = vlistCreate();
   vlistDefNtsteps(vlistID2, vlistNtsteps(vlistID1));
 
-  const auto tisID2 = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
-  if (operatorID == ADISIT)
-    {
-      vlistDefVarParam(vlistID2, tisID2, cdiEncodeParam(20, 255, 255));
-      cdiDefKeyString(vlistID2, tisID2, CDI_KEY_NAME, "to");
-      cdiDefKeyString(vlistID2, tisID2, CDI_KEY_LONGNAME, "Sea water temperature");
-      cdiDefKeyString(vlistID2, tisID2, CDI_KEY_STDNAME, "sea_water_temperature");
-    }
-  else
-    {
-      vlistDefVarParam(vlistID2, tisID2, cdiEncodeParam(2, 255, 255));
-      cdiDefKeyString(vlistID2, tisID2, CDI_KEY_NAME, "tho");
-      cdiDefKeyString(vlistID2, tisID2, CDI_KEY_LONGNAME, "Sea water potential temperature");
-      cdiDefKeyString(vlistID2, tisID2, CDI_KEY_STDNAME, "sea_water_potential_temperature");
-    }
+  const int tisID2 = vlistDefVar(vlistID2, gridID, zaxisID, TIME_VARYING);
+
+  outputSettingFuc(vlistID2, tisID2);
   cdiDefKeyString(vlistID2, tisID2, CDI_KEY_UNITS, units);
   vlistDefVarMissval(vlistID2, tisID2, tis[0].missval);
   vlistDefVarDatatype(vlistID2, tisID2, datatype);
@@ -256,6 +240,75 @@ Adisit(void *process)
   const auto streamID2 = cdo_open_write(1);
   cdo_def_vlist(streamID2, vlistID2);
 
+  return IOSettings{streamID2, vlistID2, gridsize, nlevels, taxisID1, taxisID2, tisID2, saoID2};
+}
+
+void *
+Adisit(void *process)
+{
+  int thoID = -1, saoID = -1;
+  char units[CDI_MAX_NAME] = { 0 };
+
+  cdo_initialize(process);
+
+  const int ADISIT = cdo_operator_add("adisit", 0, 0, "");
+  const int ADIPOT = cdo_operator_add("adipot", 0, 0, "");
+
+  const int operatorID = cdo_operator_id();
+
+  const CdoStreamID streamID1 = cdo_open_read(0);
+  const int vlistID1 = cdo_stream_inq_vlist(streamID1);
+
+  const auto nvars = vlistNvars(vlistID1);
+
+  const std::string cname_ADISIT{"sea_water_potential_temperature"};
+  const std::string cname_ADIPOT{"sea_water_temperature"};
+  const std::string cname = std::string{(operatorID == ADISIT) ?  cname_ADISIT : cname_ADIPOT};
+
+  for (int varID = 0; varID < nvars; ++varID)
+    {
+      const int code = getCode(vlistID1, varID, cname);
+
+      if (code == 2) {
+        thoID = varID;
+      } else if (code == 20 && operatorID == ADIPOT) {
+        thoID = varID;
+      } else if (code == 5)
+        saoID = varID;
+    }
+
+  if (saoID == -1) cdo_abort("Sea water salinity not found!");
+  if (thoID == -1) cdo_abort("%s temperature not found!", (operatorID == ADISIT) ? "Potential" : "Insitu");
+
+  auto outputSetting_ADISIT = [](const int vlistID2, const int tisID2) {
+    vlistDefVarParam(vlistID2, tisID2, cdiEncodeParam(20, 255, 255));
+    cdiDefKeyString(vlistID2, tisID2, CDI_KEY_NAME, "to");
+    cdiDefKeyString(vlistID2, tisID2, CDI_KEY_LONGNAME, "Sea water temperature");
+    cdiDefKeyString(vlistID2, tisID2, CDI_KEY_STDNAME, "sea_water_temperature");
+  };
+
+  auto outputSetting_ADIPOT = [](const int vlistID2, const int tisID2) {
+    vlistDefVarParam(vlistID2, tisID2, cdiEncodeParam(2, 255, 255));
+    cdiDefKeyString(vlistID2, tisID2, CDI_KEY_NAME, "tho");
+    cdiDefKeyString(vlistID2, tisID2, CDI_KEY_LONGNAME, "Sea water potential temperature");
+    cdiDefKeyString(vlistID2, tisID2, CDI_KEY_STDNAME, "sea_water_potential_temperature");
+  };
+
+  auto outputSettingFuc = (operatorID == ADISIT) ? outputSetting_ADISIT : outputSetting_ADIPOT;
+
+  FieldVector tho, sao, tis;
+  Varray<double> pressure;
+  const auto& configResults = configureOutput(outputSettingFuc, vlistID1, thoID, saoID, units, tho, sao, tis, pressure);
+
+  const CdoStreamID streamID2 = configResults.streamID2;
+  const int vlistID2 = configResults.vlistID2;
+  const size_t gridsize = configResults.gridsize;
+  const int nlevels = configResults.nlevels;
+  const int taxisID1 = configResults.taxisID1;
+  const int taxisID2 = configResults.taxisID2;
+  const int tisID2 = configResults.tisID2;
+  const int saoID2 = configResults.saoID2;
+
   int tsID = 0;
   while (true)
     {
