@@ -20,20 +20,20 @@
 #include "datetime.h"
 #include "sellist.h"
 #include "printinfo.h"
+#include "param_conversion.h"
 #include "progress.h"
 #include "cdi_lockedIO.h"
 
-double date_str_to_double(const char *datestr, int opt);
 
 int cdo_read_timestepmask(const char *maskfile, std::vector<bool> &imask);
 
 std::string
-dom_to_string(int64_t date)
+dom_to_string(CdiDate date)
 {
   int year, month, day;
-  cdiDecodeDate(date, &year, &month, &day);
+  cdiDate_decode(date, &year, &month, &day);
 
-  const char *cmons[] = { "", "jan", "feb", "mar", "apr", "may", "jun", "jul", "aug", "sep", "oct", "nov", "dec" };
+  const char *cmons[] = { "", "JAN", "FEB", "MAR", "APR", "MAY", "JUN", "JUL", "AUG", "SEP", "OCT", "NOV", "DEC" };
   if (month < 0 || month > 12) month = 0;
   char cstr[32];
   snprintf(cstr, sizeof(cstr), "%d%s", day, cmons[month]);
@@ -99,7 +99,7 @@ eval_timestepmask(const char *maskfile, KVList &kvlist)
 }
 
 const char *
-steptypeName(const int tsteptype)
+get_steptype_name(const int tsteptype)
 {
   // clang-format off
   if      (tsteptype == TSTEP_INSTANT)  return "instant";
@@ -132,7 +132,6 @@ Select(void *process)
   auto hasConstVars = true;
   CdoStreamID streamID2 = CDO_STREAM_UNDEF;
   int nvars, nvars2 = 0;
-  int varID, levelID;
   int last_year = -999999999;
   char paramstr[32];
   char gname[CDI_MAX_NAME];
@@ -141,7 +140,7 @@ Select(void *process)
   int taxisID2 = CDI_UNDEFID;
   int ntsteps2 = 0;
   auto doTimeSel = false;
-  std::vector<bool> vars;
+  std::vector<bool> processVars;
   Varray2D<double> vardata2;
   Field field;
   double fstartdate = -99999999999.0;
@@ -247,12 +246,12 @@ Select(void *process)
 
           vlistClearFlag(vlistID1);
           nvars = vlistNvars(vlistID1);
-          vars.resize(nvars);
+          processVars.resize(nvars);
 
           if (operatorID == DELETE)
             {
               xresult = false;
-              for (varID = 0; varID < nvars; ++varID)
+              for (int varID = 0; varID < nvars; ++varID)
                 {
                   for (int levID = 0; levID < varList1[varID].nlevels; ++levID) vlistDefFlag(vlistID1, varID, levID, true);
                 }
@@ -269,7 +268,7 @@ Select(void *process)
                     || SELINFO_NVAL(timestep_of_year) || SELINFO_NVAL(timestep) || SELINFO_NVAL(year) || SELINFO_NVAL(month)
                     || SELINFO_NVAL(day) || SELINFO_NVAL(hour) || SELINFO_NVAL(minute) || SELINFO_NVAL(dom);
 
-          for (varID = 0; varID < nvars; ++varID)
+          for (int varID = 0; varID < nvars; ++varID)
             {
               code = varList1[varID].code;
 
@@ -291,37 +290,41 @@ Select(void *process)
               gridName(gridInqType(varList1[varID].gridID), gname);
               gridname = gname;
 
-              steptype = steptypeName(varList1[varID].tsteptype);
-
-              vars[varID] = false;
+              steptype = (varList1[varID].timetype == TIME_CONSTANT) ? "constant" : "varying";
 
               const auto found_code = SELINFO_CHECK(code);
               const auto found_name = SELINFO_CHECK(name);
               const auto found_param = SELINFO_CHECK(param);
               const auto found_grid = SELINFO_CHECK(gridnum);
               const auto found_gname = SELINFO_CHECK(gridname);
-              const auto found_stype = SELINFO_CHECK(steptype);
               const auto found_ltype = SELINFO_CHECK(ltype);
               const auto found_zaxis = SELINFO_CHECK(zaxisnum);
               const auto found_zname = SELINFO_CHECK(zaxisname);
+              auto found_stype = SELINFO_CHECK(steptype);
+
+              if (SELINFO_NVAL(steptype) && !found_stype)
+                {
+                  steptype = get_steptype_name(varList1[varID].tsteptype);
+                  found_stype = SELINFO_CHECK(steptype);
+                }
 
-              bool lvar = (found_code || found_name || found_param);
               bool lstep = SELINFO_NVAL(steptype) ? found_stype : true;
+              bool lvar = (found_code || found_name || found_param);
               bool lgrid = (SELINFO_NVAL(gridnum) || SELINFO_NVAL(gridname)) ? (found_grid || found_gname) : true;
               bool lvert = (SELINFO_NVAL(ltype) || SELINFO_NVAL(zaxisnum) || SELINFO_NVAL(zaxisname))
                                ? (found_ltype || found_zaxis || found_zname)
                                : true;
 
-              if (lvar && lgrid && lvert && lstep) vars[varID] = true;
+              processVars[varID] = (lvar && lgrid && lvert && lstep);
 
-              if (!vars[varID] && !lvar && !findVariable)
+              if (!processVars[varID] && !lvar && !findVariable)
                 {
                   if (found_grid || found_gname)
-                    vars[varID] = true;
+                    processVars[varID] = true;
                   else if (found_stype)
-                    vars[varID] = true;
+                    processVars[varID] = true;
                   else if (found_ltype || found_zaxis || found_zname)
-                    vars[varID] = true;
+                    processVars[varID] = true;
                   else if (!doVarSel && (SELINFO_NVAL(levidx) || SELINFO_NVAL(level) || SELINFO_NVAL(levrange)))
                     {
                       const auto nlevels = varList1[varID].nlevels;
@@ -329,30 +332,30 @@ Select(void *process)
                         {
                           levidx = levID + 1;
                           level = cdo_zaxis_inq_level(zaxisID, levID);
-                          if (!vars[varID] && SELINFO_CHECK(levidx)) vars[varID] = true;
-                          if (!vars[varID] && SELINFO_CHECK(level)) vars[varID] = true;
-                          if (!vars[varID] && SELINFO_CHECK_RANGE(levrange, level)) vars[varID] = true;
+                          if (!processVars[varID] && SELINFO_CHECK(levidx)) processVars[varID] = true;
+                          if (!processVars[varID] && SELINFO_CHECK(level)) processVars[varID] = true;
+                          if (!processVars[varID] && SELINFO_CHECK_RANGE(levrange, level)) processVars[varID] = true;
                         }
                     }
                 }
             }
 
-          for (varID = 0; varID < nvars; ++varID)
+          for (int varID = 0; varID < nvars; ++varID)
             {
-              if (vars[varID])
+              if (processVars[varID])
                 {
                   const auto zaxisID = varList1[varID].zaxisID;
                   if (zaxisInqType(zaxisID) == ZAXIS_HYBRID)
                     {
                       const auto psvarid = vlist_get_psvarid(vlistID1, zaxisID);
-                      if (psvarid != -1 && !vars[psvarid]) vars[psvarid] = true;
+                      if (psvarid != -1 && !processVars[psvarid]) processVars[psvarid] = true;
                     }
                 }
             }
 
-          for (varID = 0; varID < nvars; ++varID)
+          for (int varID = 0; varID < nvars; ++varID)
             {
-              if (vars[varID])
+              if (processVars[varID])
                 {
                   const auto zaxisID = varList1[varID].zaxisID;
                   const auto nlevels = varList1[varID].nlevels;
@@ -406,9 +409,9 @@ Select(void *process)
             {
               if (doVarSel && doTimeSel)
                 {
-                  for (varID = 0; varID < nvars; ++varID)
+                  for (int varID = 0; varID < nvars; ++varID)
                     {
-                      if (vars[varID] == true && varList1[varID].timetype == TIME_CONSTANT)
+                      if (processVars[varID] && varList1[varID].timetype == TIME_CONSTANT)
                         {
                           copyConstVars = true;
                           break;
@@ -422,9 +425,9 @@ Select(void *process)
                 {
                   copyConstVars = true;
 
-                  for (varID = 0; varID < nvars; ++varID)
+                  for (int varID = 0; varID < nvars; ++varID)
                     {
-                      vars[varID] = true;
+                      processVars[varID] = true;
                       const auto nlevels = varList1[varID].nlevels;
                       for (int levID = 0; levID < nlevels; ++levID) vlistDefFlag(vlistID1, varID, levID, true);
                     }
@@ -438,7 +441,7 @@ Select(void *process)
           // if (Options::cdoVerbose) vlistPrint(vlistID1);
 
           vlistID0 = vlistDuplicate(vlistID1);
-          for (varID = 0; varID < nvars; ++varID)
+          for (int varID = 0; varID < nvars; ++varID)
             {
               for (int levID = 0; levID < varList1[varID].nlevels; ++levID)
                 vlistDefFlag(vlistID0, varID, levID, vlistInqFlag(vlistID1, varID, levID));
@@ -461,6 +464,7 @@ Select(void *process)
 
           if (ntsteps == 1 && nfiles == 1)
             {
+              int varID;
               for (varID = 0; varID < nvars2; ++varID)
                 if (varList2[varID].timetype != TIME_CONSTANT) break;
 
@@ -472,7 +476,7 @@ Select(void *process)
           if (ntsteps2 == 0 && nfiles > 1)
             {
               hasConstVars = false;
-              for (varID = 0; varID < nvars2; ++varID) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
+              for (int varID = 0; varID < nvars2; ++varID) vlistDefVarTimetype(vlistID2, varID, TIME_VARYING);
             }
 
           const auto nsel = SELINFO_NVAL(timestep);
@@ -503,7 +507,7 @@ Select(void *process)
                     }
                 }
 
-              for (int i = 0; i < nsel; i++)
+              for (int i = 0; i < nsel; ++i)
                 {
                   int ptimestep;
                   SELINFO_GET_VAL(timestep, i, &ptimestep);
@@ -553,11 +557,10 @@ Select(void *process)
                 }
 
               dtlist.taxis_inq_timestep(taxisID1, 0);
-              const auto vdate = dtlist.get_vdate(0);
-              const auto vtime = dtlist.get_vtime(0);
-              int second;
-              cdiDecodeDate(vdate, &year, &month, &day);
-              cdiDecodeTime(vtime, &hour, &minute, &second);
+              const auto vDateTime = dtlist.get_vDateTime(0);
+              int second, ms;
+              cdiDate_decode(vDateTime.date, &year, &month, &day);
+              cdiTime_decode(vDateTime.time, &hour, &minute, &second, &ms);
               (void) (season);  // CDO_UNUSED
 
               if (year != last_year)
@@ -574,18 +577,18 @@ Select(void *process)
               if (!copyTimestep && SELINFO_NVAL(date) == 0 && SELINFO_NVAL(timestep) == 0 && SELINFO_NVAL(timestep_of_year) == 0
                   && SELINFO_NVAL(dom) == 0)
                 {
-                  bool lseason = false, lyear = false, lmonth = false, lday = false, lhour = false, lminute = false;
-
-                  if (SELINFO_NVAL(season) == 0 || SELINFO_CHECK_SEASON(season, month)) lseason = true;
-                  if (SELINFO_NVAL(year) == 0 || SELINFO_CHECK(year)) lyear = true;
-                  if (SELINFO_NVAL(month) == 0 || SELINFO_CHECK(month)) lmonth = true;
-                  if (SELINFO_NVAL(day) == 0 || SELINFO_CHECK(day)) lday = true;
-                  if (SELINFO_NVAL(hour) == 0 || SELINFO_CHECK(hour)) lhour = true;
-                  if (SELINFO_NVAL(minute) == 0 || SELINFO_CHECK(minute)) lminute = true;
+                  const auto lseason = (SELINFO_NVAL(season) == 0 || SELINFO_CHECK_SEASON(season, month));
+                  const auto lyear = (SELINFO_NVAL(year) == 0 || SELINFO_CHECK(year));
+                  const auto lmonth = (SELINFO_NVAL(month) == 0 || SELINFO_CHECK(month));
+                  const auto lday = (SELINFO_NVAL(day) == 0 || SELINFO_CHECK(day));
+                  const auto lhour = (SELINFO_NVAL(hour) == 0 || SELINFO_CHECK(hour));
+                  const auto lminute = (SELINFO_NVAL(minute) == 0 || SELINFO_CHECK(minute));
 
                   if (lseason && lyear && lmonth && lday && lhour && lminute) copyTimestep = true;
                 }
 
+              const auto vdate = cdiDate_get(vDateTime.date);
+              const auto vtime = cdiTime_get(vDateTime.time);
               const double fdate = ((double) vdate) + ((double) vtime) / 1000000.0;
 
               if (SELINFO_NVAL(enddate))
@@ -610,14 +613,14 @@ Select(void *process)
 
               if (SELINFO_NVAL(date))
                 {
-                  const auto datetimeString = datetime_to_string(vdate, vtime);
+                  const auto datetimeString = datetime_to_string(vDateTime);
                   date = datetimeString.c_str();
                   if (SELINFO_CHECK_DATE(date)) copyTimestep = true;
                 }
 
               if (SELINFO_NVAL(dom))
                 {
-                  const auto domString = dom_to_string(vdate);
+                  const auto domString = dom_to_string(vDateTime.date);
                   dom = domString.c_str();
                   if (SELINFO_CHECK_DATE(dom)) copyTimestep = true;
                 }
@@ -643,6 +646,7 @@ Select(void *process)
 
               for (int recID = 0; recID < nrecs; ++recID)
                 {
+                  int varID, levelID;
                   cdo_inq_record(streamID1, &varID, &levelID);
                   if (vlistInqFlag(vlistID0, varID, levelID) == true)
                     {
@@ -675,6 +679,7 @@ Select(void *process)
             {
               for (int recID = 0; recID < nrecs; ++recID)
                 {
+                  int varID, levelID;
                   cdo_inq_record(streamID1, &varID, &levelID);
                   if (vlistInqFlag(vlistID0, varID, levelID) == true)
                     {
