@@ -83,7 +83,7 @@ sel_region_cell(std::vector<char> &mask, size_t gridsize, const Varray<double> &
 #ifdef _OPENMP
 #pragma omp parallel for schedule(dynamic) default(shared)
 #endif
-  for (size_t i = 0; i < gridsize; i++)
+  for (size_t i = 0; i < gridsize; ++i)
     {
       if (mask[i]) continue;
 
@@ -94,7 +94,7 @@ sel_region_cell(std::vector<char> &mask, size_t gridsize, const Varray<double> &
         }
     }
 
-  for (size_t i = 0; i < gridsize; i++)
+  for (size_t i = 0; i < gridsize; ++i)
     {
       if (mask[i]) cellidx.push_back(i);
     }
@@ -120,7 +120,7 @@ generate_region_grid(int gridID1, long &gridsize2, std::vector<long> &cellidx, i
   cdo_grid_to_degree(gridID1, CDI_YAXIS, yvals.size(), yvals.data(), "grid center lat");
 
   std::vector<char> mask(gridsize, false);
-  for (int i = 0; i < numFiles; i++)
+  for (int i = 0; i < numFiles; ++i)
     {
       Regions regions;
       const auto param = cdo_operator_argv(i).c_str();
@@ -217,8 +217,8 @@ selcircle_get_parameter(CirclePoint &cpoint)
       for (const auto &kv : kvlist)
         {
           const auto &key = kv.key;
-          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key.c_str());
-          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key.c_str());
+          if (kv.nvalues > 1) cdo_abort("Too many values for parameter key >%s<!", key);
+          if (kv.nvalues < 1) cdo_abort("Missing value for parameter key >%s<!", key);
           const auto &value = kv.values[0];
 
           // clang-format off
@@ -226,7 +226,7 @@ selcircle_get_parameter(CirclePoint &cpoint)
           else if (key == "lon")       cpoint.lon = parameter_to_double(value);
           else if (key == "lat")       cpoint.lat = parameter_to_double(value);
           else if (key == "radius")    cpoint.radius = radius_str_to_deg(value.c_str());
-          else cdo_abort("Invalid parameter key >%s<!", key.c_str());
+          else cdo_abort("Invalid parameter key >%s<!", key);
           // clang-format on
         }
     }
@@ -282,7 +282,7 @@ Selregion(void *process)
       cpoint.lat *= DEG2RAD;
     }
 
-  for (int index = 0; index < ngrids; index++)
+  for (int index = 0; index < ngrids; ++index)
     {
       auto &region = regions[index];
       const auto gridID1 = vlistGrid(vlistID1, index);
@@ -310,18 +310,13 @@ Selregion(void *process)
 
               vlistChangeGridIndex(vlistID2, index, gridID2);
 
-              for (int varID = 0; varID < nvars; varID++)
+              for (int varID = 0; varID < nvars; ++varID)
                 if (gridID1 == vlistInqVarGrid(vlistID1, varID)) varIDs[varID] = true;
             }
         }
-      else if (gridtype == GRID_GENERIC && gridInqXsize(gridID1) <= 1 && gridInqYsize(gridID1) <= 1)
-        {
-        }
       else
         {
-          cdo_print("Unsupported grid type: %s", gridNamePtr(gridtype));
-          if (gridtype == GRID_GAUSSIAN_REDUCED) cdo_print("Use option -R to convert Gaussian reduced grid to a regular grid!");
-          cdo_abort("Unsupported grid type!");
+          cdo_abort("Unsupported grid type: %s", gridNamePtr(gridtype));
         }
     }
 
@@ -343,7 +338,7 @@ Selregion(void *process)
       cdo_taxis_copy_timestep(taxisID2, taxisID1);
       cdo_def_timestep(streamID2, tsID);
 
-      for (int recID = 0; recID < nrecs; recID++)
+      for (int recID = 0; recID < nrecs; ++recID)
         {
           int varID, levelID;
           cdo_inq_record(streamID1, &varID, &levelID);
@@ -356,7 +351,7 @@ Selregion(void *process)
             {
               const auto gridID1 = varList1[varID].gridID;
               int index;
-              for (index = 0; index < ngrids; index++)
+              for (index = 0; index < ngrids; ++index)
                 if (gridID1 == regions[index].gridID1) break;
               if (index == ngrids) cdo_abort("Internal problem, grid not found!");
 
