@@ -12,68 +12,21 @@
       Yearmonstat   yearmonavg         Yearly average from monthly data
 */
 
-#include <cdi.h>
+#include "cdi.h"
+#include "calendar.h"
 
 #include "cdo_options.h"
 #include "cdo_vlist.h"
 #include "process_int.h"
-#include "calendar.h"
 #include "datetime.h"
 #include "printinfo.h"
 
-// init valid values
-template <typename T1, typename T2>
-static void
-field2_vinit(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, const T2 missval, int dpm)
-{
-  for (size_t i = 0; i < len; i++) v1[i] = (DBL_IS_EQUAL(v2[i], missval)) ? 0 : dpm;
-}
-
-static void
-field2_vinit(Field &field1, const Field &field2, int dpm)
-{
-  if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
-
-  if (field1.memType == MemType::Float && field2.memType == MemType::Float)
-    field2_vinit(field1.size, field1.vec_f, field2.vec_f, (float) field1.missval, dpm);
-  else if (field1.memType == MemType::Double && field2.memType == MemType::Float)
-    field2_vinit(field1.size, field1.vec_d, field2.vec_f, (float) field1.missval, dpm);
-  else
-    field2_vinit(field1.size, field1.vec_d, field2.vec_d, field1.missval, dpm);
-
-  field1.nmiss = field2.nmiss;
-}
-
-// increment valid values
-template <typename T1, typename T2>
-static void
-field2_vincr(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, const T2 missval, int dpm)
-{
-  for (size_t i = 0; i < len; i++)
-    if (!DBL_IS_EQUAL(v2[i], missval)) v1[i] += dpm;
-}
-
-static void
-field2_vincr(Field &field1, const Field &field2, int dpm)
-{
-  if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
-
-  if (field1.memType == MemType::Float && field2.memType == MemType::Float)
-    field2_vincr(field1.size, field1.vec_f, field2.vec_f, (float) field1.missval, dpm);
-  else if (field1.memType == MemType::Double && field2.memType == MemType::Float)
-    field2_vincr(field1.size, field1.vec_d, field2.vec_f, (float) field1.missval, dpm);
-  else
-    field2_vincr(field1.size, field1.vec_d, field2.vec_d, field1.missval, dpm);
-
-  field1.nmiss = field2.nmiss;
-}
 
 void *
 Yearmonstat(void *process)
 {
   TimeStat timestat_date = TimeStat::MEAN;
-  int64_t vdate0 = 0;
-  int vtime0 = 0;
+  CdiDateTime vDateTime0 = { };
   int year0 = 0, month0 = 0;
   int year, month, day;
 
@@ -134,24 +87,27 @@ Yearmonstat(void *process)
           if (nrecs == 0) break;
 
           dtlist.taxis_inq_timestep(taxisID1, nsets);
-          const auto vdate = dtlist.get_vdate(nsets);
-          const auto vtime = dtlist.get_vtime(nsets);
-          cdiDecodeDate(vdate, &year, &month, &day);
+          const auto vDateTime = dtlist.get_vDateTime(nsets);
+          cdiDate_decode(vDateTime.date, &year, &month, &day);
 
           if (nsets == 0) year0 = year;
 
-          if (year != year0) break;
+          if (year != year0)
+            {
+              cdo_add_steps(-1);
+              break;
+            }
 
           if (nsets > 0 && month == month0)
             {
-              cdo_warning("   last timestep: %s %s", date_to_string(vdate0).c_str(), time_to_string(vtime0).c_str());
-              cdo_warning("current timestep: %s %s", date_to_string(vdate).c_str(), time_to_string(vtime).c_str());
+              cdo_warning("   last timestep: %s", datetime_to_string(vDateTime0));
+              cdo_warning("current timestep: %s", datetime_to_string(vDateTime));
               cdo_abort("Month does not change!");
             }
 
           const auto dpm = days_per_month(calendar, year, month);
 
-          for (int recID = 0; recID < nrecs; recID++)
+          for (int recID = 0; recID < nrecs; ++recID)
             {
               int varID, levelID;
               cdo_inq_record(streamID1, &varID, &levelID);
@@ -196,8 +152,7 @@ Yearmonstat(void *process)
             }
 
           month0 = month;
-          vdate0 = vdate;
-          vtime0 = vtime;
+          vDateTime0 = vDateTime;
           nsets++;
           dsets += dpm;
           tsID++;
@@ -205,11 +160,10 @@ Yearmonstat(void *process)
 
       if (nrecs == 0 && nsets == 0) break;
 
-      for (int varID = 0; varID < nvars; varID++)
+      for (int varID = 0; varID < nvars; ++varID)
         {
           if (varList[varID].timetype == TIME_CONSTANT) continue;
-          const auto nlevels = varList[varID].nlevels;
-          for (int levelID = 0; levelID < nlevels; levelID++)
+          for (int levelID = 0; levelID < varList[varID].nlevels; ++levelID)
             {
               const auto &rsamp1 = samp1[varID][levelID];
               auto &rvars1 = vars1[varID][levelID];
@@ -221,12 +175,12 @@ Yearmonstat(void *process)
         }
 
       if (Options::cdoVerbose)
-        cdo_print("%s %s  nsets = %ld", date_to_string(vdate0).c_str(), time_to_string(vtime0).c_str(), nsets);
+        cdo_print("%s  nsets = %ld", datetime_to_string(vDateTime0), nsets);
 
       dtlist.stat_taxis_def_timestep(taxisID2, nsets);
       cdo_def_timestep(streamID2, otsID);
 
-      for (int recID = 0; recID < maxrecs; recID++)
+      for (int recID = 0; recID < maxrecs; ++recID)
         {
           if (otsID && recList[recID].lconst) continue;
 
