@@ -125,8 +125,8 @@ compare_grid_unstructured(int gridID1, int gridID2)
       gridInqXvals(gridID2, xvals2.data());
       gridInqYvals(gridID2, yvals2.data());
 
-      // size_t inc = gridsize > 10000 ? gridsize / 1000 : 1;
-      size_t inc = 1;
+      // size_t inc = (gridsize > 10000) ? gridsize / 1000 : 1;
+      constexpr size_t inc = 1;
       for (size_t i = 0; i < gridsize; i += inc)
         if (std::fabs(xvals1[i] - xvals2[i]) > 2.e-5 || std::fabs(yvals1[i] - yvals2[i]) > 2.e-5)
           {
@@ -232,21 +232,21 @@ zaxisCheckLevels(int zaxisID1, int zaxisID2)
 static void
 vlistCheckNames(int vlistID1, int vlistID2)
 {
-  int varID;
   auto nvars = vlistNvars(vlistID1);
 
   // std::vector<std::array<char,CDI_MAX_NAME>> names1(nvars); C++14?
   // std::vector<std::array<char,CDI_MAX_NAME>> names2(nvars);
   std::vector<std::vector<char>> names1(nvars), names2(nvars);
-  for (varID = 0; varID < nvars; varID++) names1[varID].resize(CDI_MAX_NAME);
-  for (varID = 0; varID < nvars; varID++) names2[varID].resize(CDI_MAX_NAME);
-  for (varID = 0; varID < nvars; varID++) vlistInqVarName(vlistID1, varID, names1[varID].data());
-  for (varID = 0; varID < nvars; varID++) vlistInqVarName(vlistID2, varID, names2[varID].data());
+  for (int varID = 0; varID < nvars; ++varID) names1[varID].resize(CDI_MAX_NAME);
+  for (int varID = 0; varID < nvars; ++varID) names2[varID].resize(CDI_MAX_NAME);
+  for (int varID = 0; varID < nvars; ++varID) vlistInqVarName(vlistID1, varID, names1[varID].data());
+  for (int varID = 0; varID < nvars; ++varID) vlistInqVarName(vlistID2, varID, names2[varID].data());
 
   std::sort(names1.begin(), names1.end());
   std::sort(names2.begin(), names2.end());
 
-  for (varID = 0; varID < nvars; varID++)
+  int varID;
+  for (varID = 0; varID < nvars; ++varID)
     if (!cdo_cmpstr(names1[varID].data(), names2[varID].data())) break;
 
   if (varID == nvars) cdo_print("Use CDO option --sortname to sort the parameter by name (NetCDF only)!");
@@ -255,21 +255,21 @@ vlistCheckNames(int vlistID1, int vlistID2)
 void
 vlistPrintMissingVars(int vlistID1, int vlistID2)
 {
-  int varID1, varID2;
   const auto nvars1 = vlistNvars(vlistID1);
   const auto nvars2 = vlistNvars(vlistID2);
 
   std::vector<std::vector<char>> names1(nvars1), names2(nvars2);
-  for (varID1 = 0; varID1 < nvars1; varID1++) names1[varID1].resize(CDI_MAX_NAME);
-  for (varID2 = 0; varID2 < nvars2; varID2++) names2[varID2].resize(CDI_MAX_NAME);
-  for (varID1 = 0; varID1 < nvars1; varID1++) vlistInqVarName(vlistID1, varID1, names1[varID1].data());
-  for (varID2 = 0; varID2 < nvars2; varID2++) vlistInqVarName(vlistID2, varID2, names2[varID2].data());
+  for (int varID1 = 0; varID1 < nvars1; ++varID1) names1[varID1].resize(CDI_MAX_NAME);
+  for (int varID2 = 0; varID2 < nvars2; ++varID2) names2[varID2].resize(CDI_MAX_NAME);
+  for (int varID1 = 0; varID1 < nvars1; ++varID1) vlistInqVarName(vlistID1, varID1, names1[varID1].data());
+  for (int varID2 = 0; varID2 < nvars2; ++varID2) vlistInqVarName(vlistID2, varID2, names2[varID2].data());
 
   if (nvars1 > nvars2)
     {
-      for (varID1 = 0; varID1 < nvars1; varID1++)
+      for (int varID1 = 0; varID1 < nvars1; ++varID1)
         {
-          for (varID2 = 0; varID2 < nvars2; varID2++)
+          int varID2;
+          for (varID2 = 0; varID2 < nvars2; ++varID2)
             {
               if (cdo_cmpstr(names1[varID1].data(), names2[varID2].data())) break;
             }
@@ -278,9 +278,10 @@ vlistPrintMissingVars(int vlistID1, int vlistID2)
     }
   else
     {
-      for (varID2 = 0; varID2 < nvars2; varID2++)
+      for (int varID2 = 0; varID2 < nvars2; ++varID2)
         {
-          for (varID1 = 0; varID1 < nvars1; varID1++)
+          int varID1;
+          for (varID1 = 0; varID1 < nvars1; ++varID1)
             {
               if (cdo_cmpstr(names1[varID1].data(), names2[varID2].data())) break;
             }
@@ -303,9 +304,9 @@ vlist_compare(int vlistID1, int vlistID2, int flag)
     }
 
   if (vlistNrecs(vlistID1) != vlistNrecs(vlistID2))
-    cdo_abort("Input streams have different number of %s per timestep!", nvars == 1 ? "layers" : "records");
+    cdo_abort("Input streams have different number of %s per timestep!", (nvars == 1) ? "layers" : "records");
 
-  for (int varID = 0; varID < nvars; varID++)
+  for (int varID = 0; varID < nvars; ++varID)
     {
       if (nvars > 1)
         {
@@ -358,7 +359,7 @@ vlist_compare_x(int vlistID1, int vlistID2, int flag)
 
   if (nvars2 != 1) cdo_abort("Internal problem, vlist_compare_x() called with unexpected vlistID2 argument!");
 
-  for (int varID = 0; varID < nvars; varID++)
+  for (int varID = 0; varID < nvars; ++varID)
     {
       if (flag & CMP_GRIDSIZE)
         {
@@ -386,27 +387,27 @@ vlist_compare_x(int vlistID1, int vlistID2, int flag)
 void
 vlist_map(int vlistID1, int vlistID2, int flag, int mapflag, std::map<int, int> &mapOfVarIDs)
 {
-  int varID1, varID2;
   const auto nvars1 = vlistNvars(vlistID1);
   const auto nvars2 = vlistNvars(vlistID2);
 
   std::vector<std::vector<char>> names1(nvars1), names2(nvars2);
-  for (varID1 = 0; varID1 < nvars1; varID1++) names1[varID1].resize(CDI_MAX_NAME);
-  for (varID2 = 0; varID2 < nvars2; varID2++) names2[varID2].resize(CDI_MAX_NAME);
-  for (varID1 = 0; varID1 < nvars1; varID1++) vlistInqVarName(vlistID1, varID1, names1[varID1].data());
-  for (varID2 = 0; varID2 < nvars2; varID2++) vlistInqVarName(vlistID2, varID2, names2[varID2].data());
+  for (int varID1 = 0; varID1 < nvars1; ++varID1) names1[varID1].resize(CDI_MAX_NAME);
+  for (int varID2 = 0; varID2 < nvars2; ++varID2) names2[varID2].resize(CDI_MAX_NAME);
+  for (int varID1 = 0; varID1 < nvars1; ++varID1) vlistInqVarName(vlistID1, varID1, names1[varID1].data());
+  for (int varID2 = 0; varID2 < nvars2; ++varID2) vlistInqVarName(vlistID2, varID2, names2[varID2].data());
 
   if (mapflag == 2)
     {
-      for (varID2 = 0; varID2 < nvars2; varID2++)
+      for (int varID2 = 0; varID2 < nvars2; ++varID2)
         {
-          for (varID1 = 0; varID1 < nvars1; varID1++)
+          int  varID1;
+          for (varID1 = 0; varID1 < nvars1; ++varID1)
             {
               if (cdo_cmpstr(names1[varID1].data(), names2[varID2].data())) break;
             }
           if (varID1 == nvars1)
             {
-              cdo_abort("Variable %s not found!", names2[varID2].data());
+              cdo_abort("Variable %s not found in first stream!", names2[varID2].data());
             }
           else
             {
@@ -416,16 +417,17 @@ vlist_map(int vlistID1, int vlistID2, int flag, int mapflag, std::map<int, int>
     }
   else
     {
-      for (varID1 = 0; varID1 < nvars1; varID1++)
+      for (int varID1 = 0; varID1 < nvars1; ++varID1)
         {
-          for (varID2 = 0; varID2 < nvars2; varID2++)
+          int varID2;
+          for (varID2 = 0; varID2 < nvars2; ++varID2)
             {
               if (cdo_cmpstr(names1[varID1].data(), names2[varID2].data())) break;
             }
           if (varID2 == nvars2)
             {
               if (mapflag == 3) continue;
-              cdo_abort("Variable %s not found!", names1[varID1].data());
+              cdo_abort("Variable %s not found in second stream!", names1[varID1].data());
             }
           else
             {
@@ -434,10 +436,10 @@ vlist_map(int vlistID1, int vlistID2, int flag, int mapflag, std::map<int, int>
         }
     }
 
-  if (mapOfVarIDs.empty()) cdo_abort("No variable found!");
+  if (mapOfVarIDs.empty()) cdo_abort("No variable found that occurs in both streams!");
 
   if (Options::cdoVerbose)
-    for (varID1 = 0; varID1 < nvars1; varID1++)
+    for (int varID1 = 0; varID1 < nvars1; ++varID1)
       {
         const auto &it = mapOfVarIDs.find(varID1);
         if (it != mapOfVarIDs.end())
@@ -446,7 +448,7 @@ vlist_map(int vlistID1, int vlistID2, int flag, int mapflag, std::map<int, int>
 
   if (mapOfVarIDs.size() > 1)
     {
-      varID2 = mapOfVarIDs.begin()->second;
+      auto varID2 = mapOfVarIDs.begin()->second;
       for (auto it = ++mapOfVarIDs.begin(); it != mapOfVarIDs.end(); ++it)
         {
           if (it->second < varID2)
@@ -458,8 +460,8 @@ vlist_map(int vlistID1, int vlistID2, int flag, int mapflag, std::map<int, int>
 
   for (auto it = mapOfVarIDs.begin(); it != mapOfVarIDs.end(); ++it)
     {
-      varID1 = it->first;
-      varID2 = it->second;
+      const auto varID1 = it->first;
+      const auto varID2 = it->second;
 
       if (flag & CMP_GRIDSIZE)
         {
@@ -487,7 +489,7 @@ bool
 vlist_is_szipped(int vlistID)
 {
   const auto nvars = vlistNvars(vlistID);
-  for (int varID = 0; varID < nvars; varID++)
+  for (int varID = 0; varID < nvars; ++varID)
     {
       const auto comptype = vlistInqVarCompType(vlistID, varID);
       if (comptype == CDI_COMPRESS_SZIP) return true;
@@ -539,116 +541,120 @@ vlist_check_gridsize(int vlistID)
   return ngp;
 }
 
-void
-vlist_read_vct(int vlistID, int *rzaxisIDh, int *rnvct, int *rnhlev, int *rnhlevf, int *rnhlevh, Varray<double> &vct)
+Varray<double>
+vlist_read_vct(int vlistID, int &zaxisID_ML, int &numHybridLevels, int &numFullLevels, int &numHalfLevels)
 {
-  int zaxisIDh = -1;
-  int nhlev = 0, nhlevf = 0, nhlevh = 0;
-  int nvct = 0;
+  Varray<double> vct;
+  int vctSize = 0;
+  zaxisID_ML = -1;
+  numHybridLevels = 0;
+  numFullLevels = 0;
+  numHalfLevels = 0;
 
-  auto lhavevct = false;
+  auto haveVCT = false;
   auto nzaxis = vlistNzaxis(vlistID);
   for (int iz = 0; iz < nzaxis; ++iz)
     {
-      // bool mono_level = false;
-      auto mono_level = true;
-      auto zaxisID = vlistZaxis(vlistID, iz);
-      auto nlevel = zaxisInqSize(zaxisID);
-      auto zaxistype = zaxisInqType(zaxisID);
+      // auto monoLevel = false;
+      auto monoLevel = true;
+      const auto zaxisID = vlistZaxis(vlistID, iz);
+      const auto nlevels = zaxisInqSize(zaxisID);
+      const auto zaxistype = zaxisInqType(zaxisID);
 
       if (Options::cdoVerbose)
-        cdo_print("ZAXIS_HYBRID=%d ZAXIS_HYBRID_HALF=%d nlevel=%d mono_level=%d", zaxisInqType(zaxisID) == ZAXIS_HYBRID,
-                  zaxisInqType(zaxisID) == ZAXIS_HYBRID_HALF, nlevel, mono_level);
+        cdo_print("ZAXIS_HYBRID=%d ZAXIS_HYBRID_HALF=%d nlevels=%d monoLevel=%d", zaxisInqType(zaxisID) == ZAXIS_HYBRID,
+                  zaxisInqType(zaxisID) == ZAXIS_HYBRID_HALF, nlevels, monoLevel);
 
-      if ((zaxistype == ZAXIS_HYBRID || zaxistype == ZAXIS_HYBRID_HALF) && nlevel > 1 && !mono_level)
+      if ((zaxistype == ZAXIS_HYBRID || zaxistype == ZAXIS_HYBRID_HALF) && nlevels > 1 && !monoLevel)
         {
-          Varray<double> level(nlevel);
+          Varray<double> level(nlevels);
           cdo_zaxis_inq_levels(zaxisID, &level[0]);
           int l;
-          for (l = 0; l < nlevel; l++)
+          for (l = 0; l < nlevels; ++l)
             {
               if ((l + 1) != (int) (level[l] + 0.5)) break;
             }
-          if (l == nlevel) mono_level = true;
+          if (l == nlevels) monoLevel = true;
         }
 
-      if ((zaxistype == ZAXIS_HYBRID || zaxistype == ZAXIS_HYBRID_HALF) && nlevel > 1 && mono_level)
+      if ((zaxistype == ZAXIS_HYBRID || zaxistype == ZAXIS_HYBRID_HALF) && nlevels > 1 && monoLevel)
         {
-          nvct = zaxisInqVctSize(zaxisID);
-          if (nlevel == (nvct / 2 - 1))
+          vctSize = zaxisInqVctSize(zaxisID);
+          if (nlevels == (vctSize / 2 - 1))
             {
-              if (!lhavevct)
+              if (!haveVCT)
                 {
-                  lhavevct = true;
-                  zaxisIDh = zaxisID;
-                  nhlev = nlevel;
-                  nhlevf = nhlev;
-                  nhlevh = nhlevf + 1;
+                  haveVCT = true;
+                  zaxisID_ML = zaxisID;
+                  numHybridLevels = nlevels;
+                  numFullLevels = numHybridLevels;
+                  numHalfLevels = numFullLevels + 1;
 
-                  vct.resize(nvct);
+                  vct.resize(vctSize);
                   zaxisInqVct(zaxisID, vct.data());
                   if (Options::cdoVerbose)
-                    cdo_print("Detected half-level model definition : nlevel == (nvct/2 - 1) (nlevel: %d, nvct: %d, nhlevf: %d, "
-                              "nhlevh: %d) ",
-                              nlevel, nvct, nhlevf, nhlevh);
+                    cdo_print("Detected half-level model definition : nlevels == (vctSize/2 - 1) (nlevels: %d, vctSize: %d, "
+                              "numFullLevels: %d, numHalfLevels: %d) ",
+                              nlevels, vctSize, numFullLevels, numHalfLevels);
                 }
             }
-          else if (nlevel == (nvct / 2))
+          else if (nlevels == (vctSize / 2))
             {
-              if (!lhavevct)
+              if (!haveVCT)
                 {
-                  lhavevct = true;
-                  zaxisIDh = zaxisID;
-                  nhlev = nlevel;
-                  nhlevf = nhlev - 1;
-                  nhlevh = nhlev;
+                  haveVCT = true;
+                  zaxisID_ML = zaxisID;
+                  numHybridLevels = nlevels;
+                  numFullLevels = numHybridLevels - 1;
+                  numHalfLevels = numHybridLevels;
 
-                  vct.resize(nvct);
+                  vct.resize(vctSize);
                   zaxisInqVct(zaxisID, vct.data());
                   if (Options::cdoVerbose)
                     cdo_print(
-                        "Detected full-level model definition : nlevel == (nvct/2) (nlevel: %d, nvct: %d, nhlevf: %d, nhlevh: %d) ",
-                        nlevel, nvct, nhlevf, nhlevh);
+                        "Detected full-level model definition : nlevels == (vctSize/2) (nlevels: %d, vctSize: %d, "
+                        "numFullLevels: %d, numHalfLevels: %d) ",
+                        nlevels, vctSize, numFullLevels, numHalfLevels);
                 }
             }
-          else if (nlevel == (nvct - 4 - 1))
+          else if (nlevels == (vctSize - 4 - 1))
             {
-              if (!lhavevct)
+              if (!haveVCT)
                 {
-                  Varray<double> rvct(nvct);
-                  zaxisInqVct(zaxisID, rvct.data());
+                  Varray<double> vctRead(vctSize);
+                  zaxisInqVct(zaxisID, vctRead.data());
 
-                  int voff = 4;
-                  if ((int) (rvct[0] + 0.5) == 100000 && rvct[voff] < rvct[voff + 1])
+                  constexpr int voff = 4;
+                  if ((int) (vctRead[0] + 0.5) == 100000 && vctRead[voff] < vctRead[voff + 1])
                     {
-                      lhavevct = true;
-                      zaxisIDh = zaxisID;
-                      nhlev = nlevel;
-                      nhlevf = nhlev;
-                      nhlevh = nhlev + 1;
+                      haveVCT = true;
+                      zaxisID_ML = zaxisID;
+                      numHybridLevels = nlevels;
+                      numFullLevels = numHybridLevels;
+                      numHalfLevels = numFullLevels + 1;
 
-                      int vctsize = 2 * nhlevh;
+                      int vctsize = 2 * numHalfLevels;
                       vct.resize(vctsize);
 
                       // calculate VCT for LM
 
-                      for (int i = 0; i < vctsize / 2; i++)
+                      for (int i = 0; i < vctsize / 2; ++i)
                         {
-                          if (rvct[voff + i] >= rvct[voff] && rvct[voff + i] <= rvct[3])
+                          if (vctRead[voff + i] >= vctRead[voff] && vctRead[voff + i] <= vctRead[3])
                             {
-                              vct[i] = rvct[0] * rvct[voff + i];
+                              vct[i] = vctRead[0] * vctRead[voff + i];
                               vct[vctsize / 2 + i] = 0;
                             }
                           else
                             {
-                              vct[i] = (rvct[0] * rvct[3] * (1 - rvct[voff + i])) / (1 - rvct[3]);
-                              vct[vctsize / 2 + i] = (rvct[voff + i] - rvct[3]) / (1 - rvct[3]);
+                              vct[i] = (vctRead[0] * vctRead[3] * (1 - vctRead[voff + i])) / (1 - vctRead[3]);
+                              vct[vctsize / 2 + i] = (vctRead[voff + i] - vctRead[3]) / (1 - vctRead[3]);
                             }
                         }
 
                       if (Options::cdoVerbose)
                         {
-                          for (int i = 0; i < vctsize / 2; i++)
+                          for (int i = 0; i < vctsize / 2; ++i)
                             fprintf(stdout, "%5d %25.17f %25.17f\n", i, vct[i], vct[vctsize / 2 + i]);
                         }
                     }
@@ -657,39 +663,35 @@ vlist_read_vct(int vlistID, int *rzaxisIDh, int *rnvct, int *rnhlev, int *rnhlev
         }
     }
 
-  *rzaxisIDh = zaxisIDh;
-  *rnvct = nvct;
-  *rnhlev = nhlev;
-  *rnhlevf = nhlevf;
-  *rnhlevh = nhlevh;
+  return vct;
 }
 
 void
 vlist_change_hybrid_zaxis(int vlistID1, int vlistID2, int zaxisID1, int zaxisID2)
 {
-  int nvct0 = 0;
+  int vctSize0 = 0;
   Varray<double> vct;
 
   const auto nzaxis = vlistNzaxis(vlistID1);
   for (int i = 0; i < nzaxis; ++i)
     {
       const auto zaxisID = vlistZaxis(vlistID1, i);
-      const auto nlevel = zaxisInqSize(zaxisID);
+      const auto nlevels = zaxisInqSize(zaxisID);
 
-      if (zaxisID == zaxisID1 && nlevel > 1)
+      if (zaxisID == zaxisID1 && nlevels > 1)
         {
-          const auto nvct = zaxisInqVctSize(zaxisID);
+          const auto vctSize = zaxisInqVctSize(zaxisID);
           if (!vct.size())
             {
-              nvct0 = nvct;
-              vct.resize(nvct);
+              vctSize0 = vctSize;
+              vct.resize(vctSize);
               zaxisInqVct(zaxisID, vct.data());
 
               vlistChangeZaxisIndex(vlistID2, i, zaxisID2);
             }
           else
             {
-              if (nvct0 == nvct && memcmp(vct.data(), zaxisInqVctPtr(zaxisID), nvct * sizeof(double)) == 0)
+              if (vctSize0 == vctSize && memcmp(vct.data(), zaxisInqVctPtr(zaxisID), vctSize * sizeof(double)) == 0)
                 vlistChangeZaxisIndex(vlistID2, i, zaxisID2);
             }
         }
@@ -723,7 +725,7 @@ vlist_get_first_spectral_grid(int vlistID)
 {
   // find first spectral grid
   const auto ngrids = vlistNgrids(vlistID);
-  for (int index = 0; index < ngrids; index++)
+  for (int index = 0; index < ngrids; ++index)
     {
       const auto gridID = vlistGrid(vlistID, index);
       if (gridInqType(gridID) == GRID_SPECTRAL) return gridID;
@@ -737,7 +739,7 @@ vlist_get_first_gaussian_grid(int vlistID)
 {
   // find first gaussian grid
   const auto ngrids = vlistNgrids(vlistID);
-  for (int index = 0; index < ngrids; index++)
+  for (int index = 0; index < ngrids; ++index)
     {
       const auto gridID = vlistGrid(vlistID, index);
       if (gridInqType(gridID) == GRID_GAUSSIAN) return gridID;
@@ -751,7 +753,7 @@ vlist_get_first_fourier_grid(int vlistID)
 {
   // find first fourier grid
   const auto ngrids = vlistNgrids(vlistID);
-  for (int index = 0; index < ngrids; index++)
+  for (int index = 0; index < ngrids; ++index)
     {
       const auto gridID = vlistGrid(vlistID, index);
       if (gridInqType(gridID) == GRID_FOURIER) return gridID;
@@ -765,10 +767,10 @@ cdo_check_missval(double missval, const char *varname)
 {
   if (DBL_IS_EQUAL(0, missval) || DBL_IS_EQUAL(1, missval))
     {
-      static bool lwarn = true;
-      if (lwarn)
+      static auto printWarning = true;
+      if (printWarning)
         {
-          lwarn = false;
+          printWarning = false;
           cdo_warning("Variable %s has a missing value of %g, this can lead to incorrect results with this operator!", varname,
                       missval);
         }
