@@ -13,10 +13,6 @@
 #include "field.h"
 
 // clang-format off
-auto memtype_is_float_float   = [](auto a, auto b) { return (a == MemType::Float  && b == MemType::Float); };
-auto memtype_is_double_float  = [](auto a, auto b) { return (a == MemType::Double && b == MemType::Float); };
-// auto memtype_is_float_double  = [](auto a, auto b) { return (a == MemType::Float  && b == MemType::Double); };
-// auto memtype_is_double_double = [](auto a, auto b) { return (a == MemType::Double && b == MemType::Double); };
 
 // arithmetic
 auto arith_add   = [](const double a, const double b) { return a + b; };
@@ -26,7 +22,7 @@ auto arith_div   = [](const double a, const double b) { return a / b; };
 auto arith_min   = [](const auto a, const auto b) { return (b > a) ? a : b; };
 auto arith_max   = [](const auto a, const auto b) { return (b < a) ? a : b; };
 auto arith_sumq  = [](const double a, const double b) { return a + b * b; };
-// auto arith_atan2 = [](const double a, const double b) { return std::atan2(a, b); };
+auto arith_atan2 = [](const double a, const double b) { return std::atan2(a, b); };
 
 // arithmetic with missing values
 auto arith_add_mv = [](auto &a, const auto mv_a, const auto b, const auto mv_b, auto isEQ)
@@ -45,10 +41,8 @@ auto arith_sum_mv = [](auto &a, const auto mv_a, const auto b, const auto mv_b,
                     { if (!isEQ(b, mv_b)) a = (isEQ(a, mv_a) ? b : arith_add(a, b)); };
 auto arith_sumq_mv = [](auto &a, const auto mv_a, const auto b, const auto mv_b, auto isEQ)
                      { if (!isEQ(b, mv_b)) a = (isEQ(a, mv_a) ? arith_mul(b, b) : arith_sumq(a, b)); };
-/*
 auto arith_atan2_mv = [](auto &a, const auto mv_a, const auto b, const auto mv_b, auto isEQ)
                       { a = (isEQ(a, mv_a) || isEQ(b, mv_b)) ? mv_a : arith_atan2(a, b); };
-*/
 auto arith_vinit_mv = [](auto &a, const auto mv_a, const auto b, const auto mv_b, auto isEQ)
                       { a = !isEQ(b, mv_b); (void)mv_a; };
 auto arith_vincr_mv = [](auto &a, const auto mv_a, const auto b, const auto mv_b, auto isEQ)
@@ -65,7 +59,13 @@ varray2_div(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, const double
   assert(len <= v1.size());
   assert(len <= v2.size());
 
-  for (size_t i = 0; i < len; ++i) v1[i] = is_equal(v2[i], 0.0) ? missval1 : arith_div(v1[i], v2[i]);
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
+#endif
+  for (size_t i = 0; i < len; ++i)
+    {
+      v1[i] = is_equal(v2[i], 0.0) ? missval1 : arith_div(v1[i], v2[i]);
+    }
 }
 
 template <typename T1, typename T2, typename FUNC>
@@ -78,7 +78,13 @@ varray2_arith(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, FUNC func)
   assert(len <= v1.size());
   assert(len <= v2.size());
 
-  for (size_t i = 0; i < len; ++i) v1[i] = func(v1[i], v2[i]);
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
+#endif
+  for (size_t i = 0; i < len; ++i)
+    {
+      v1[i] = func(v1[i], v2[i]);
+    }
 }
 
 template <typename T1, typename T2, typename FUNC>
@@ -97,14 +103,14 @@ varray2_arith_mv(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, const d
   if (std::isnan(missval1) || std::isnan(missval2))
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < len; ++i) func(v1[i], mv1, v2[i], mv2, dbl_is_equal);
     }
   else
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
       for (size_t i = 0; i < len; ++i) func(v1[i], mv1, v2[i], mv2, is_equal);
     }
@@ -118,6 +124,8 @@ field2_vinit(Field &field1, const Field &field2)
 
   if (memtype_is_float_float(field1.memType, field2.memType))
     varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_vinit_mv);
+  else if (memtype_is_float_double(field1.memType, field2.memType))
+    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_vinit_mv);
   else if (memtype_is_double_float(field1.memType, field2.memType))
     varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_vinit_mv);
   else
@@ -134,6 +142,8 @@ field2_vincr(Field &field1, const Field &field2)
 
   if (memtype_is_float_float(field1.memType, field2.memType))
     varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_vincr_mv);
+  else if (memtype_is_float_double(field1.memType, field2.memType))
+    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_vincr_mv);
   else if (memtype_is_double_float(field1.memType, field2.memType))
     varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_vincr_mv);
   else
@@ -142,6 +152,57 @@ field2_vincr(Field &field1, const Field &field2)
   field1.nmiss = field2.nmiss;
 }
 
+// init valid values
+template <typename T1, typename T2>
+static void
+field2_vinit(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, const T2 missval, int vinit)
+{
+  for (size_t i = 0; i < len; ++i) v1[i] = (DBL_IS_EQUAL(v2[i], missval)) ? 0 : vinit;
+}
+
+void
+field2_vinit(Field &field1, const Field &field2, int vinit)
+{
+  if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
+
+  if (memtype_is_float_float(field1.memType, field2.memType))
+    field2_vinit(field1.size, field1.vec_f, field2.vec_f, (float) field1.missval, vinit);
+  else if (memtype_is_float_double(field1.memType, field2.memType))
+    field2_vinit(field1.size, field1.vec_f, field2.vec_d, field1.missval, vinit);
+  else if (memtype_is_double_float(field1.memType, field2.memType))
+    field2_vinit(field1.size, field1.vec_d, field2.vec_f, (float) field1.missval, vinit);
+  else
+    field2_vinit(field1.size, field1.vec_d, field2.vec_d, field1.missval, vinit);
+
+  field1.nmiss = field2.nmiss;
+}
+
+// increment valid values
+template <typename T1, typename T2>
+static void
+field2_vincr(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, const T2 missval, int vincr)
+{
+  for (size_t i = 0; i < len; ++i)
+    if (!DBL_IS_EQUAL(v2[i], missval)) v1[i] += vincr;
+}
+
+void
+field2_vincr(Field &field1, const Field &field2, int vincr)
+{
+  if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
+
+  if (memtype_is_float_float(field1.memType, field2.memType))
+    field2_vincr(field1.size, field1.vec_f, field2.vec_f, (float) field1.missval, vincr);
+  else if (memtype_is_float_double(field1.memType, field2.memType))
+    field2_vincr(field1.size, field1.vec_f, field2.vec_d, field1.missval, vincr);
+  else if (memtype_is_double_float(field1.memType, field2.memType))
+    field2_vincr(field1.size, field1.vec_d, field2.vec_f, (float) field1.missval, vincr);
+  else
+    field2_vincr(field1.size, field1.vec_d, field2.vec_d, field1.missval, vincr);
+
+  field1.nmiss = field2.nmiss;
+}
+
 void
 field2_add(Field &field1, const Field &field2)
 {
@@ -151,6 +212,8 @@ field2_add(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_add_mv);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_add_mv);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_add_mv);
       else
@@ -162,6 +225,8 @@ field2_add(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_add);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_add);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_add);
       else
@@ -178,6 +243,8 @@ field2_sum(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_sum_mv);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_sum_mv);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_sum_mv);
       else
@@ -189,6 +256,8 @@ field2_sum(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_add);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_add);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_add);
       else
@@ -209,7 +278,10 @@ field2_sumw(Field &field1, const Field &field2, double w)
 
   if (field1.nmiss || field2.nmiss)
     {
-      for (size_t i = 0; i < len; i++)
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
+#endif
+      for (size_t i = 0; i < len; ++i)
         if (!DBL_IS_EQUAL(array2[i], missval2))
           {
             if (!DBL_IS_EQUAL(array1[i], missval1))
@@ -223,9 +295,9 @@ field2_sumw(Field &field1, const Field &field2, double w)
   else
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(len, array1, array2, w)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
-      for (size_t i = 0; i < len; i++) array1[i] += w * array2[i];
+      for (size_t i = 0; i < len; ++i) array1[i] += w * array2[i];
     }
 }
 
@@ -252,7 +324,7 @@ field2_sumtr(Field &occur, const Field &field, const double refval)
 #ifdef _OPENMP
 #pragma omp parallel for default(shared) schedule(static)
 #endif
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         if (!DBL_IS_EQUAL(farray[i], fmissval))
           {
             if (!DBL_IS_EQUAL(oarray[i], omissval))
@@ -270,9 +342,9 @@ field2_sumtr(Field &occur, const Field &field, const double refval)
   else
     {
 #ifdef _OPENMP
-#pragma omp parallel for default(shared)
+#pragma omp parallel for default(shared) schedule(static)
 #endif
-      for (size_t i = 0; i < len; i++) oarray[i] = (DBL_IS_EQUAL(farray[i], refval)) ? 0.0 : oarray[i] + 1.0;
+      for (size_t i = 0; i < len; ++i) oarray[i] = (DBL_IS_EQUAL(farray[i], refval)) ? 0.0 : oarray[i] + 1.0;
     }
 }
 
@@ -285,6 +357,8 @@ field2_sumq(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_sumq_mv);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_sumq_mv);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_sumq_mv);
       else
@@ -296,6 +370,8 @@ field2_sumq(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_sumq);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_sumq);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_sumq);
       else
@@ -323,7 +399,10 @@ field2_sumqw(Field &field1, const Field &field2, const double w)
 
   if (field1.nmiss || field2.nmiss)
     {
-      for (size_t i = 0; i < len; i++)
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
+#endif
+      for (size_t i = 0; i < len; ++i)
         if (!DBL_IS_EQUAL(array2[i], missval2))
           {
             if (!DBL_IS_EQUAL(array1[i], missval1))
@@ -336,7 +415,10 @@ field2_sumqw(Field &field1, const Field &field2, const double w)
     }
   else
     {
-      for (size_t i = 0; i < len; i++) array1[i] += w * array2[i] * array2[i];
+#ifdef _OPENMP
+#pragma omp parallel for default(shared) schedule(static)
+#endif
+      for (size_t i = 0; i < len; ++i) array1[i] += w * array2[i] * array2[i];
     }
 }
 
@@ -349,6 +431,8 @@ field2_sub(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_sub_mv);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_sub_mv);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_sub_mv);
       else
@@ -360,6 +444,8 @@ field2_sub(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_sub);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_sub);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_sub);
       else
@@ -376,6 +462,8 @@ field2_mul(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_mul_mv);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_mul_mv);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_mul_mv);
       else
@@ -387,6 +475,8 @@ field2_mul(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_mul);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_mul);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_mul);
       else
@@ -403,6 +493,8 @@ field2_div(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_div_mv);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_div_mv);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_div_mv);
       else
@@ -414,6 +506,8 @@ field2_div(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_div(field1.size, field1.vec_f, field2.vec_f, field1.missval);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_div(field1.size, field1.vec_f, field2.vec_d, field1.missval);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_div(field1.size, field1.vec_d, field2.vec_f, field1.missval);
       else
@@ -429,11 +523,13 @@ field2_atan2(Field &field1, const Field &field2)
   if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
 
   if (memtype_is_float_float(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_div_mv);
+    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_atan2_mv);
+  else if (memtype_is_float_double(field1.memType, field2.memType))
+    varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_atan2_mv);
   else if (memtype_is_double_float(field1.memType, field2.memType))
-    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_div_mv);
+    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_atan2_mv);
   else
-    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_div_mv);
+    varray2_arith_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval, arith_atan2_mv);
 
   field_num_mv(field1);
 }
@@ -450,7 +546,7 @@ field2_set_miss(Field &field1, const Field &field2)
 
   if (field1.nmiss)
     {
-      for (size_t i = 0; i < len; i++) array1[i] = DBL_IS_EQUAL(array1[i], missval1) ? array2[i] : array1[i];
+      for (size_t i = 0; i < len; ++i) array1[i] = DBL_IS_EQUAL(array1[i], missval1) ? array2[i] : array1[i];
 
       field1.nmiss = field_num_miss(field1);
     }
@@ -465,6 +561,8 @@ field2_min(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_min_mv);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_min_mv);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_min_mv);
       else
@@ -476,6 +574,8 @@ field2_min(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_min);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_min);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_min);
       else
@@ -492,6 +592,8 @@ field2_max(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval, arith_max_mv);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval, arith_max_mv);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval, arith_max_mv);
       else
@@ -503,6 +605,8 @@ field2_max(Field &field1, const Field &field2)
     {
       if (memtype_is_float_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_f, field2.vec_f, arith_max);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_arith(field1.size, field1.vec_f, field2.vec_d, arith_max);
       else if (memtype_is_double_float(field1.memType, field2.memType))
         varray2_arith(field1.size, field1.vec_d, field2.vec_f, arith_max);
       else
@@ -533,7 +637,7 @@ field2_minidx(size_t nmiss3, size_t len, double missval3, Field &field1, Field &
 
   if (field2.nmiss || nmiss3)
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         {
           if (DBL_IS_EQUAL(v3[i], missval3))
             {
@@ -550,7 +654,7 @@ field2_minidx(size_t nmiss3, size_t len, double missval3, Field &field1, Field &
     }
   else
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         {
           if (v3[i] < v2[i]) field2_set_index(v1[i], v2[i], v3[i], idx);
         }
@@ -580,7 +684,7 @@ field2_maxidx(size_t nmiss3, size_t len, double missval3, Field &field1, Field &
 
   if (field2.nmiss || nmiss3)
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         {
           if (DBL_IS_EQUAL(v3[i], missval3))
             {
@@ -597,7 +701,7 @@ field2_maxidx(size_t nmiss3, size_t len, double missval3, Field &field1, Field &
     }
   else
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         {
           if (v3[i] > v2[i]) field2_set_index(v1[i], v2[i], v3[i], idx);
         }
@@ -623,7 +727,7 @@ field_set_nmiss(const size_t len, Varray<double> &v, double missval)
 
   if (std::isnan(missval))
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         if (DBL_IS_EQUAL(v[i], missval) || v[i] < 0)
           {
             v[i] = missval;
@@ -632,7 +736,7 @@ field_set_nmiss(const size_t len, Varray<double> &v, double missval)
     }
   else
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         if (IS_EQUAL(v[i], missval) || v[i] < 0)
           {
             v[i] = missval;
@@ -657,7 +761,7 @@ field2_var(Field &field1, const Field &field2, const Field &field3, const int di
 
   if (field1.nmiss || field2.nmiss)
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         {
           const auto temp = DIVMN(MULMN(array1[i], array1[i]), array3[i]);
           array1[i] = DIVMN(SUBMN(array2[i], temp), array3[i] - divisor);
@@ -666,7 +770,7 @@ field2_var(Field &field1, const Field &field2, const Field &field3, const int di
     }
   else
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         {
           const auto temp = DIV(MUL(array1[i], array1[i]), array3[i]);
           array1[i] = DIV(SUB(array2[i], temp), array3[i] - divisor);
@@ -689,7 +793,7 @@ field2_std(Field &field1, const Field &field2, const Field &field3, const int di
   field2_var(field1, field2, field3, divisor);
 
   size_t nmiss = 0;
-  for (size_t i = 0; i < len; i++)
+  for (size_t i = 0; i < len; ++i)
     if (DBL_IS_EQUAL(array1[i], missval1) || array1[i] < 0)
       {
         array1[i] = missval1;
@@ -717,11 +821,11 @@ fieldc_var(Field &field1, const Field &field2, const int nsets, const int diviso
 
   if (nsetx == 0)
     {
-      for (size_t i = 0; i < len; i++) array1[i] = missval1;
+      for (size_t i = 0; i < len; ++i) array1[i] = missval1;
     }
   else if (field1.nmiss || field2.nmiss)
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         {
           temp = MULMN(array1[i], array1[i]) / nsets;
           array1[i] = SUBMN(array2[i], temp) / nsetx;
@@ -730,7 +834,7 @@ fieldc_var(Field &field1, const Field &field2, const int nsets, const int diviso
     }
   else
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         {
           temp = MUL(array1[i], array1[i]) / nsets;
           array1[i] = SUB(array2[i], temp) / nsetx;
@@ -753,7 +857,7 @@ fieldc_std(Field &field1, const Field &field2, const int nsets, const int diviso
   fieldc_var(field1, field2, nsets, divisor);
 
   size_t nmiss = 0;
-  for (size_t i = 0; i < len; i++)
+  for (size_t i = 0; i < len; ++i)
     if (DBL_IS_EQUAL(array1[i], missval1) || array1[i] < 0)
       {
         array1[i] = missval1;
@@ -780,7 +884,7 @@ field2_moq(Field &field1, const Field &field2)
 
   if (field2.nmiss)
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         if (!DBL_IS_EQUAL(array2[i], missval2))
           array1[i] = array2[i] * array2[i];
         else
@@ -790,7 +894,7 @@ field2_moq(Field &field1, const Field &field2)
     }
   else
     {
-      for (size_t i = 0; i < len; i++) array1[i] = array2[i] * array2[i];
+      for (size_t i = 0; i < len; ++i) array1[i] = array2[i] * array2[i];
     }
 }
 
@@ -807,7 +911,7 @@ field2_moqw(Field &field1, const Field &field2, const double w)
 
   if (field2.nmiss)
     {
-      for (size_t i = 0; i < len; i++)
+      for (size_t i = 0; i < len; ++i)
         if (!DBL_IS_EQUAL(array2[i], missval2))
           array1[i] = w * array2[i] * array2[i];
         else
@@ -817,13 +921,12 @@ field2_moqw(Field &field1, const Field &field2, const double w)
     }
   else
     {
-      for (size_t i = 0; i < len; i++) array1[i] = w * array2[i] * array2[i];
+      for (size_t i = 0; i < len; ++i) array1[i] = w * array2[i] * array2[i];
     }
 }
 
 /**
- * Counts the number of nonmissing values. The result of the operation
- * is computed according to the following rules:
+ * Counts the number of nonmissing values. The result of the operation is computed according to the following rules:
  *
  * field1  field2  result
  * a       b       a + 1
@@ -834,34 +937,61 @@ field2_moqw(Field &field1, const Field &field2, const double w)
  * @param field1 the 1st input field, also holds the result
  * @param field2 the 2nd input field
  */
+template <typename T1, typename T2>
+static void
+varray2_count_mv(const size_t len, Varray<T1> &v1, const Varray<T2> &v2, const double mv1, const double mv2)
+{
+  assert(len > 0);
+  assert(v1.size() > 0);
+  assert(v2.size() > 0);
+  assert(len <= v1.size());
+  assert(len <= v2.size());
+
+  for (size_t i = 0; i < len; ++i)
+    if (!DBL_IS_EQUAL(v2[i], mv2))
+      {
+        if (!DBL_IS_EQUAL(v1[i], mv1))
+          v1[i] += 1.0;
+        else
+          v1[i] = 1.0;
+      }
+}
+
+template <typename T>
+static void
+varray2_count(const size_t len, Varray<T> &v)
+{
+  assert(len > 0);
+
+  for (size_t i = 0; i < len; ++i)  v[i] += 1.0;
+}
+
 void
 field2_count(Field &field1, const Field &field2)
 {
-  const auto missval1 = field1.missval;
-  const auto missval2 = field2.missval;
-  auto &array1 = field1.vec_d;
-  const auto &array2 = field2.vec_d;
-
-  const auto len = field1.size;
-  if (len != field2.size) cdo_abort("Fields have different size (%s)", __func__);
+  if (field1.size != field2.size) cdo_abort("Fields have different size (%s)", __func__);
 
   if (field1.nmiss || field2.nmiss)
     {
-      for (size_t i = 0; i < len; i++)
-        if (!DBL_IS_EQUAL(array2[i], missval2))
-          {
-            if (!DBL_IS_EQUAL(array1[i], missval1))
-              array1[i] += 1.0;
-            else
-              array1[i] = 1.0;
-          }
+      if (memtype_is_float_float(field1.memType, field2.memType))
+        varray2_count_mv(field1.size, field1.vec_f, field2.vec_f, field1.missval, field2.missval);
+      else if (memtype_is_float_double(field1.memType, field2.memType))
+        varray2_count_mv(field1.size, field1.vec_f, field2.vec_d, field1.missval, field2.missval);
+      else if (memtype_is_double_float(field1.memType, field2.memType))
+        varray2_count_mv(field1.size, field1.vec_d, field2.vec_f, field1.missval, field2.missval);
+      else
+        varray2_count_mv(field1.size, field1.vec_d, field2.vec_d, field1.missval, field2.missval);
 
       field1.nmiss = field_num_miss(field1);
     }
   else
     {
-      for (size_t i = 0; i < len; i++) array1[i] += 1.0;
+      if (field1.memType == MemType::Float)
+        varray2_count(field1.size, field1.vec_f);
+      else
+        varray2_count(field1.size, field1.vec_d);
     }
+
 }
 
 void
