@@ -20,6 +20,7 @@ static const module_t module_Arithc         = {"Arithc"         ,Arithc
 static const module_t module_Arithdays      = {"Arithdays"      ,Arithdays      , ArithdaysHelp     , ArithdaysOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Arithlat       = {"Arithlat"       ,Arithlat       , ArithlatHelp      , ArithlatOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Apply          = {"Apply"          ,nullptr        , ApplyHelp         , {"apply"}               , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Bitrounding    = {"Bitrounding"    ,Bitrounding    , BitroundingHelp   , BitroundingOperators    , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Cat            = {"Cat"            ,Cat            , CopyHelp          , CatOperators            , EXPOSED  , CDI_REAL , -1 , 1     , NoRestriction };
 static const module_t module_CDItest        = {"CDItest"        ,CDItest        , {}                , CDItestOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_CDIread        = {"CDIread"        ,CDIread        , {}                , CDIreadOperators        , EXPOSED  , CDI_REAL , 1  , 0     , NoRestriction };
@@ -41,6 +42,7 @@ static const module_t module_Condc          = {"Condc"          ,Condc
 static const module_t module_Consecstat     = {"Consecstat"     ,Consecstat     , ConsecstatHelp    , ConsecstatOperators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Copy           = {"Copy"           ,Copy           , CopyHelp          , CopyOperators           , EXPOSED  , CDI_REAL , -1 , 1     , NoRestriction };
 static const module_t module_DCW_util       = {"DCW_util"       ,DCW_util       , {}                , DCW_utilOperators       , EXPOSED  , CDI_REAL , 0  , 0     , NoRestriction };
+static const module_t module_Dayarith       = {"Dayarith"       ,Dayarith       , DayarithHelp      , DayarithOperators       , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
 static const module_t module_Deltat         = {"Deltat"         ,Deltat         , DeltatHelp        , DeltatOperators         , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Deltime        = {"Deltime"        ,Deltime        , {}                , DeltimeOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Depth          = {"Depth"          ,Depth          , {}                , DepthOperators          , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
@@ -49,6 +51,7 @@ static const module_t module_Detrend        = {"Detrend"        ,Detrend
 static const module_t module_Diff           = {"Diff"           ,Diff           , DiffHelp          , DiffOperators           , EXPOSED  , CDI_BOTH , 2  , 0     , NoRestriction,   {Alias ("diffv", "diffn")}};
 static const module_t module_Distgrid       = {"Distgrid"       ,Distgrid       , DistgridHelp      , DistgridOperators       , EXPOSED  , CDI_REAL , 1  , OBASE , NoRestriction };
 static const module_t module_Duplicate      = {"Duplicate"      ,Duplicate      , DuplicateHelp     , DuplicateOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Echam5ini      = {"Echam5ini"      ,Echam5ini      , {}                , Echam5iniOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Enlarge        = {"Enlarge"        ,Enlarge        , EnlargeHelp       , EnlargeOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Enlargegrid    = {"Enlargegrid"    ,Enlargegrid    , {}                , EnlargegridOperators    , INTERNAL , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Ensstat        = {"Ensstat"        ,Ensstat        , EnsstatHelp       , EnsstatOperators        , EXPOSED  , CDI_REAL , -1 , 1     , NoRestriction };
@@ -128,7 +131,7 @@ static const module_t module_Remapycon2     = {"Remapycon2"     ,Remap
 static const module_t module_Remapscon      = {"Remapscon"      ,Remap          , {}                , RemapsconOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Remapcon2      = {"Remapcon2"      ,Remap          , Remapcon2Help     , Remapcon2Operators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Remaplaf       = {"Remaplaf"       ,Remap          , RemaplafHelp      , RemaplafOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
-static const module_t module_Remapstat      = {"Remapstat"      ,Remapstat      , {}                , RemapstatOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
+static const module_t module_Remapstat      = {"Remapstat"      ,Remapstat      , RemapstatHelp     , RemapstatOperators      , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Remapavg       = {"Remapavg"       ,Remap          , {}                , RemapavgOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Remapweights   = {"Remapweights"   ,Remapweights   , {}                , RemapweightsOperators   , EXPOSED  , CDI_REAL , 0  , 0     , NoRestriction };
 static const module_t module_Remapeta       = {"Remapeta"       ,Remapeta       , RemapetaHelp      , RemapetaOperators       , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
@@ -148,7 +151,7 @@ static const module_t module_Selgridcell    = {"Selgridcell"    ,Selgridcell
 static const module_t module_Select         = {"Select"         ,Select         , SelectHelp        , SelectOperators         , EXPOSED  , CDI_BOTH , -1 , 1     , NoRestriction };
 static const module_t module_Selvar         = {"Selvar"         ,Selvar         , SelvarHelp        , SelvarOperators         , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction,   {Alias ("selvar", "selname"), Alias("delvar"  , "delname"),Alias("selgridname"     , "selgrid")} };
 static const module_t module_Selrec         = {"Selrec"         ,Selrec         , SelvarHelp        , SelrecOperators         , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction };
-static const module_t module_Selregion      = {"Selregion"      ,Selregion      , SelcircleHelp     , SelregionOperators      , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction };
+static const module_t module_Selregion      = {"Selregion"      ,Selregion      , SelregionHelp     , SelregionOperators      , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction };
 static const module_t module_Seloperator    = {"Seloperator"    ,Seloperator    , {}                , SeloperatorOperators    , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Seltime        = {"Seltime"        ,Seltime        , SeltimeHelp       , SeltimeOperators        , EXPOSED  , CDI_BOTH , 1  , 1     , NoRestriction,   {Alias ("selseas", "selseason"), Alias("selmon", "selmonth")} };
 static const module_t module_Selyearidx     = {"Selyearidx"     ,Selyearidx     , SelyearidxHelp    , SelyearidxOperators     , EXPOSED  , CDI_REAL , 2  , 1     , NoRestriction };
@@ -200,6 +203,7 @@ static const module_t module_Monpctl        = {"Monpctl"        ,Timpctl
 static const module_t module_Daypctl        = {"Daypctl"        ,Timpctl        , DaypctlHelp       , DaypctlOperators        , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
 static const module_t module_Hourpctl       = {"Hourpctl"       ,Timpctl        , HourpctlHelp      , HourpctlOperators       , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
 static const module_t module_Timselpctl     = {"Timselpctl"     ,Timselpctl     , TimselpctlHelp    , TimselpctlOperators     , EXPOSED  , CDI_REAL , 3  , 1     , NoRestriction };
+static const module_t module_Timfill        = {"Timfill"        ,Timfill        , {}                , TimfillOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_Timsort        = {"Timsort"        ,Timsort        , TimsortHelp       , TimsortOperators        , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction,   {Alias ("sort", "timsort")} };
 static const module_t module_Timselstat     = {"Timselstat"     ,Timselstat     , TimselstatHelp    , TimselstatOperators     , EXPOSED  , CDI_REAL , 1  , 1     , NoRestriction };
 static const module_t module_XTimstat       = {"XTimstat"       ,XTimstat       , {}                , XTimstatOperators       , INTERNAL , CDI_BOTH , 1  , 1     , NoRestriction };
