@@ -28,7 +28,7 @@
 static void
 set_xyvals(const double val, const size_t nvals, double *xvals, double *yvals)
 {
-  for (size_t i = 0; i < nvals; i++)
+  for (size_t i = 0; i < nvals; ++i)
     {
       xvals[i] = val;
       yvals[i] = val;
@@ -38,7 +38,7 @@ set_xyvals(const double val, const size_t nvals, double *xvals, double *yvals)
 static void
 check_xyvals(const size_t nvals, double *xvals, double *yvals)
 {
-  for (size_t i = 0; i < nvals; i++)
+  for (size_t i = 0; i < nvals; ++i)
     {
       if (xvals[i] < -9000. || xvals[i] > 9000.) xvals[i] = -9999.;
       if (yvals[i] < -9000. || yvals[i] > 9000.) yvals[i] = -9999.;
@@ -68,9 +68,9 @@ proj_fwd_xyvals(PJ *proj, size_t nvals, double *xvals, double *yvals)
   std::atomic<size_t> atomicCountNans{0};
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(nvals, proj, atomicCountNans, xvals, yvals)
+#pragma omp parallel for default(none) shared(nvals, proj, atomicCountNans, xvals, yvals) schedule(static)
 #endif
-  for (size_t i = 0; i < nvals; i++)
+  for (size_t i = 0; i < nvals; ++i)
     {
       PJ_COORD p;
       p.uv.u = proj_torad(xvals[i]);
@@ -91,9 +91,9 @@ proj_inv_xyvals(PJ *proj, size_t nvals, double *xvals, double *yvals)
   std::atomic<size_t> atomicCountNans{0};
 
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(nvals, proj, atomicCountNans, xvals, yvals)
+#pragma omp parallel for default(none) shared(nvals, proj, atomicCountNans, xvals, yvals) schedule(static)
 #endif
-  for (size_t i = 0; i < nvals; i++)
+  for (size_t i = 0; i < nvals; ++i)
     {
       PJ_COORD p;
       p.uv.u = xvals[i];
@@ -185,7 +185,7 @@ checkUpperRange(const char *projection, const char *name, const double val, cons
 }
 
 static void
-verify_lcc_parameter(struct CDI_GridProjParams gpp)
+verify_lcc_parameter(const CDI_GridProjParams &gpp)
 {
   auto projection = "lambert_conformal_conic";
 
@@ -228,7 +228,7 @@ proj_lonlat_to_lcc(struct CDI_GridProjParams gpp, size_t nvals, double *xvals, d
 }
 
 static void
-lonlat_to_lcc(struct CDI_GridProjParams gpp, size_t nvals, double *xvals, double *yvals)
+lonlat_to_lcc(const CDI_GridProjParams &gpp, size_t nvals, double *xvals, double *yvals)
 {
   const auto status = proj_lonlat_to_lcc(gpp, nvals, xvals, yvals);
 #ifdef HAVE_LIBPROJ
@@ -239,45 +239,34 @@ lonlat_to_lcc(struct CDI_GridProjParams gpp, size_t nvals, double *xvals, double
 }
 
 int
-cdo_lonlat_to_lcc(int gridID, size_t nvals, double *xvals, double *yvals)
-{
-  struct CDI_GridProjParams gpp;
-  gridInqParamsLCC(gridID, &gpp);
-
-  lonlat_to_lcc(gpp, nvals, xvals, yvals);
-
-  return 0;
-}
-
-int
-proj_lcc_to_lonlat(struct CDI_GridProjParams *gpp, double x_0, double y_0, size_t nvals, double *xvals, double *yvals)
+proj_lcc_to_lonlat(struct CDI_GridProjParams gpp, double x_0, double y_0, size_t nvals, double *xvals, double *yvals)
 {
 #ifdef HAVE_LIBPROJ
   std::string params = "+proj=lcc ";
-  if (IS_NOT_EQUAL(gpp->a, gpp->mv) && gpp->a > 0) params += gen_param("+a=%.15g ", gpp->a);
-  if (IS_NOT_EQUAL(gpp->b, gpp->mv) && gpp->b > 0) params += gen_param("+b=%.15g ", gpp->b);
-  if (IS_NOT_EQUAL(gpp->rf, gpp->mv) && gpp->rf > 0) params += gen_param("+rf=%.15g ", gpp->rf);
-  params += gen_param("+lon_0=%.15g ", gpp->lon_0);
-  params += gen_param("+lat_0=%.15g ", gpp->lat_0);
-  params += gen_param("+lat_1=%.15g ", gpp->lat_1);
-  params += gen_param("+lat_2=%.15g ", gpp->lat_2);
-  if (IS_NOT_EQUAL(x_0, gpp->mv)) params += gen_param("+x_0=%.15g ", x_0);
-  if (IS_NOT_EQUAL(y_0, gpp->mv)) params += gen_param("+y_0=%.15g ", y_0);
+  if (IS_NOT_EQUAL(gpp.a, gpp.mv) && gpp.a > 0) params += gen_param("+a=%.15g ", gpp.a);
+  if (IS_NOT_EQUAL(gpp.b, gpp.mv) && gpp.b > 0) params += gen_param("+b=%.15g ", gpp.b);
+  if (IS_NOT_EQUAL(gpp.rf, gpp.mv) && gpp.rf > 0) params += gen_param("+rf=%.15g ", gpp.rf);
+  params += gen_param("+lon_0=%.15g ", gpp.lon_0);
+  params += gen_param("+lat_0=%.15g ", gpp.lat_0);
+  params += gen_param("+lat_1=%.15g ", gpp.lat_1);
+  params += gen_param("+lat_2=%.15g ", gpp.lat_2);
+  if (IS_NOT_EQUAL(x_0, gpp.mv)) params += gen_param("+x_0=%.15g ", x_0);
+  if (IS_NOT_EQUAL(y_0, gpp.mv)) params += gen_param("+y_0=%.15g ", y_0);
 
   const int status = do_proj_inv(params.c_str(), nvals, xvals, yvals);
 #else
   const int status = 1;
 #endif
 
-  if (status == 1) set_xyvals(gpp->mv, nvals, xvals, yvals);
+  if (status == 1) set_xyvals(gpp.mv, nvals, xvals, yvals);
 
   return status;
 }
 
 static void
-lcc_to_lonlat(struct CDI_GridProjParams gpp, size_t nvals, double *xvals, double *yvals)
+lcc_to_lonlat(const CDI_GridProjParams &gpp, size_t nvals, double *xvals, double *yvals)
 {
-  const auto status = proj_lcc_to_lonlat(&gpp, gpp.x_0, gpp.y_0, nvals, xvals, yvals);
+  const auto status = proj_lcc_to_lonlat(gpp, gpp.x_0, gpp.y_0, nvals, xvals, yvals);
 #ifdef HAVE_LIBPROJ
   if (status) cdo_abort("proj library error: %s", proj_errno_string(status));
 #else
@@ -290,10 +279,10 @@ cdo_lcc_to_lonlat(int gridID, size_t nvals, double *xvals, double *yvals)
 {
   auto projection = "lambert_conformal_conic";
 
-  struct CDI_GridProjParams gpp;
+  CDI_GridProjParams gpp;
   gridInqParamsLCC(gridID, &gpp);
 
-  bool paramIsMissing = checkValIsMiss(projection, "longitude_of_central_meridian", gpp.lon_0, gpp.mv)
+  auto paramIsMissing = checkValIsMiss(projection, "longitude_of_central_meridian", gpp.lon_0, gpp.mv)
                         || checkValIsMiss(projection, "latitude_of_projection_origin", gpp.lat_0, gpp.mv)
                         || checkValIsMiss(projection, "standard_parallel", gpp.lat_1, gpp.mv);
 
@@ -323,7 +312,7 @@ cdo_lcc_to_lonlat(int gridID, size_t nvals, double *xvals, double *yvals)
 }
 
 static void
-verify_stere_parameter(struct CDI_GridProjParams gpp)
+verify_stere_parameter(const CDI_GridProjParams &gpp)
 {
   auto projection = "polar_stereographic";
 
@@ -363,7 +352,7 @@ proj_lonlat_to_stere(struct CDI_GridProjParams gpp, size_t nvals, double *xvals,
 }
 
 static void
-lonlat_to_stere(struct CDI_GridProjParams gpp, size_t nvals, double *xvals, double *yvals)
+lonlat_to_stere(const CDI_GridProjParams &gpp, size_t nvals, double *xvals, double *yvals)
 {
   const auto status = proj_lonlat_to_stere(gpp, nvals, xvals, yvals);
 #ifdef HAVE_LIBPROJ
@@ -374,44 +363,33 @@ lonlat_to_stere(struct CDI_GridProjParams gpp, size_t nvals, double *xvals, doub
 }
 
 int
-cdo_lonlat_to_stere(int gridID, size_t nvals, double *xvals, double *yvals)
-{
-  struct CDI_GridProjParams gpp;
-  gridInqParamsSTERE(gridID, &gpp);
-
-  lonlat_to_stere(gpp, nvals, xvals, yvals);
-
-  return 0;
-}
-
-int
-proj_stere_to_lonlat(struct CDI_GridProjParams *gpp, double x_0, double y_0, size_t nvals, double *xvals, double *yvals)
+proj_stere_to_lonlat(struct CDI_GridProjParams gpp, double x_0, double y_0, size_t nvals, double *xvals, double *yvals)
 {
 #ifdef HAVE_LIBPROJ
   std::string params = "+proj=stere ";
-  if (IS_NOT_EQUAL(gpp->a, gpp->mv) && gpp->a > 0) params += gen_param("+a=%.15g ", gpp->a);
-  if (IS_NOT_EQUAL(gpp->b, gpp->mv) && gpp->b > 0) params += gen_param("+b=%.15g ", gpp->b);
-  if (IS_NOT_EQUAL(gpp->rf, gpp->mv) && gpp->rf > 0) params += gen_param("+rf=%.15g ", gpp->rf);
-  params += gen_param("+lon_0=%.15g ", gpp->lon_0);
-  params += gen_param("+lat_ts=%.15g ", gpp->lat_1);
-  params += gen_param("+lat_0=%.15g ", gpp->lat_0);
-  if (IS_NOT_EQUAL(x_0, gpp->mv)) params += gen_param("+x_0=%.15g ", x_0);
-  if (IS_NOT_EQUAL(y_0, gpp->mv)) params += gen_param("+y_0=%.15g ", y_0);
+  if (IS_NOT_EQUAL(gpp.a, gpp.mv) && gpp.a > 0) params += gen_param("+a=%.15g ", gpp.a);
+  if (IS_NOT_EQUAL(gpp.b, gpp.mv) && gpp.b > 0) params += gen_param("+b=%.15g ", gpp.b);
+  if (IS_NOT_EQUAL(gpp.rf, gpp.mv) && gpp.rf > 0) params += gen_param("+rf=%.15g ", gpp.rf);
+  params += gen_param("+lon_0=%.15g ", gpp.lon_0);
+  params += gen_param("+lat_ts=%.15g ", gpp.lat_1);
+  params += gen_param("+lat_0=%.15g ", gpp.lat_0);
+  if (IS_NOT_EQUAL(x_0, gpp.mv)) params += gen_param("+x_0=%.15g ", x_0);
+  if (IS_NOT_EQUAL(y_0, gpp.mv)) params += gen_param("+y_0=%.15g ", y_0);
 
   const int status = do_proj_inv(params.c_str(), nvals, xvals, yvals);
 #else
   const int status = 1;
 #endif
 
-  if (status == 1) set_xyvals(gpp->mv, nvals, xvals, yvals);
+  if (status == 1) set_xyvals(gpp.mv, nvals, xvals, yvals);
 
   return status;
 }
 
 static void
-stere_to_lonlat(struct CDI_GridProjParams gpp, size_t nvals, double *xvals, double *yvals)
+stere_to_lonlat(const CDI_GridProjParams &gpp, size_t nvals, double *xvals, double *yvals)
 {
-  const auto status = proj_stere_to_lonlat(&gpp, gpp.x_0, gpp.y_0, nvals, xvals, yvals);
+  const auto status = proj_stere_to_lonlat(gpp, gpp.x_0, gpp.y_0, nvals, xvals, yvals);
 #ifdef HAVE_LIBPROJ
   if (status) cdo_abort("proj library error: %s", proj_errno_string(status));
 #else
@@ -424,10 +402,10 @@ cdo_stere_to_lonlat(int gridID, size_t nvals, double *xvals, double *yvals)
 {
   auto projection = "polar_stereographic";
 
-  struct CDI_GridProjParams gpp;
+  CDI_GridProjParams gpp;
   gridInqParamsSTERE(gridID, &gpp);
 
-  bool paramIsMissing = checkValIsMiss(projection, "straight_vertical_longitude_from_pole", gpp.lon_0, gpp.mv)
+  auto paramIsMissing = checkValIsMiss(projection, "straight_vertical_longitude_from_pole", gpp.lon_0, gpp.mv)
                         || checkValIsMiss(projection, "latitude_of_projection_origin", gpp.lat_0, gpp.mv)
                         || checkValIsMiss(projection, "standard_parallel", gpp.lat_1, gpp.mv);
 
@@ -521,10 +499,11 @@ cdiInqAttConvertedToFloat(int gridID, int atttype, const char *attname, int attl
   return status;
 }
 
-static void
-grid_inq_params_laea(int gridID, struct CDI_GridProjParams *gpp)
+static CDI_GridProjParams
+grid_inq_params_laea(int gridID)
 {
-  gridProjParamsInit(gpp);
+  CDI_GridProjParams gpp;
+  gridProjParamsInit(&gpp);
 
   const auto gridtype = gridInqType(gridID);
   if (gridtype == GRID_PROJECTION)
@@ -550,14 +529,14 @@ grid_inq_params_laea(int gridID, struct CDI_GridProjParams *gpp)
               if (cdiInqAttConvertedToFloat(gridID, atttype, attname, attlen, &attflt))
                 {
                   // clang-format off
-                  if      (cdo_cmpstr(attname, "earth_radius"))                   gpp->a     = attflt;
-                  else if (cdo_cmpstr(attname, "semi_major_axis"))                gpp->a     = attflt;
-                  else if (cdo_cmpstr(attname, "semi_minor_axis"))                gpp->b     = attflt;
-                  else if (cdo_cmpstr(attname, "inverse_flattening"))             gpp->rf    = attflt;
-                  else if (cdo_cmpstr(attname, "longitude_of_projection_origin")) gpp->lon_0 = attflt;
-                  else if (cdo_cmpstr(attname, "latitude_of_projection_origin"))  gpp->lat_0 = attflt;
-                  else if (cdo_cmpstr(attname, "false_easting"))                  gpp->x_0   = attflt;
-                  else if (cdo_cmpstr(attname, "false_northing"))                 gpp->y_0   = attflt;
+                  if      (cdo_cmpstr(attname, "earth_radius"))                   gpp.a     = attflt;
+                  else if (cdo_cmpstr(attname, "semi_major_axis"))                gpp.a     = attflt;
+                  else if (cdo_cmpstr(attname, "semi_minor_axis"))                gpp.b     = attflt;
+                  else if (cdo_cmpstr(attname, "inverse_flattening"))             gpp.rf    = attflt;
+                  else if (cdo_cmpstr(attname, "longitude_of_projection_origin")) gpp.lon_0 = attflt;
+                  else if (cdo_cmpstr(attname, "latitude_of_projection_origin"))  gpp.lat_0 = attflt;
+                  else if (cdo_cmpstr(attname, "false_easting"))                  gpp.x_0   = attflt;
+                  else if (cdo_cmpstr(attname, "false_northing"))                 gpp.y_0   = attflt;
                   // clang-format on
                 }
             }
@@ -565,6 +544,8 @@ grid_inq_params_laea(int gridID, struct CDI_GridProjParams *gpp)
       else
         cdo_warning("%s mapping parameter missing!", projection);
     }
+
+  return gpp;
 }
 #endif
 
@@ -572,8 +553,7 @@ void
 cdo_laea_to_lonlat(int gridID, size_t nvals, double *xvals, double *yvals)
 {
 #ifdef HAVE_LIBPROJ
-  struct CDI_GridProjParams gpp;
-  grid_inq_params_laea(gridID, &gpp);
+  const auto gpp = grid_inq_params_laea(gridID);
 
   std::string params = "+proj=laea ";
   if (IS_NOT_EQUAL(gpp.a, gpp.mv) && gpp.a > 0) params += gen_param("+a=%.15g ", gpp.a);
@@ -615,13 +595,13 @@ gridGetPlanetRadius(int gridID)
   const auto projtype = (gridtype == GRID_PROJECTION) ? gridInqProjType(gridID) : -1;
   if (projtype == CDI_PROJ_LCC)
     {
-      struct CDI_GridProjParams gpp;
+      CDI_GridProjParams gpp;
       gridInqParamsLCC(gridID, &gpp);
       if (IS_EQUAL(gpp.b, gpp.mv)) planetRadius = gpp.a;
     }
   else if (projtype == CDI_PROJ_STERE)
     {
-      struct CDI_GridProjParams gpp;
+      CDI_GridProjParams gpp;
       gridInqParamsSTERE(gridID, &gpp);
       if (IS_EQUAL(gpp.b, gpp.mv)) planetRadius = gpp.a;
     }
