@@ -96,12 +96,12 @@ nlat_to_nlon_cubic(int nlat)
 }
 
 static void
-scale_vec(double scalefactor, size_t nvals, double *values)
+scale_vec(double scalefactor, size_t n, double *values)
 {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(nvals, scalefactor, values)
+#pragma omp parallel for if (n > 99999) default(shared) schedule(static)
 #endif
-  for (size_t n = 0; n < nvals; ++n) values[n] *= scalefactor;
+  for (size_t i = 0; i < n; ++i) values[i] *= scalefactor;
 }
 
 static void
@@ -158,7 +158,7 @@ grid_to_degree(const char *units, size_t nvals, double *values, const char *desc
 {
   if (strncmp(units, "rad", 3) == 0)
     {
-      for (size_t n = 0; n < nvals; ++n) values[n] *= RAD2DEG;
+      scale_vec(RAD2DEG, nvals, values);
     }
   else if (strncmp(units, "deg", 3) == 0)
     {
@@ -342,8 +342,8 @@ gridGenCenterRLL(int gridID, size_t nx, size_t ny, const std::vector<double> &xv
   double xpole = 0.0, ypole = 0.0, angle = 0.0;
   gridInqParamRLL(gridID, &xpole, &ypole, &angle);
 
-  for (size_t j = 0; j < ny; j++)
-    for (size_t i = 0; i < nx; i++)
+  for (size_t j = 0; j < ny; ++j)
+    for (size_t i = 0; i < nx; ++i)
       {
         xvals2D[j * nx + i] = lamrot_to_lam(yvals[j], xvals[i], ypole, xpole, angle);
         yvals2D[j * nx + i] = phirot_to_phi(yvals[j], xvals[i], ypole, angle);
@@ -360,7 +360,7 @@ gridGenBoundsRLL(int gridID, size_t nx, size_t ny, const std::vector<double> &xb
   double minlon, maxlon;
   double minlat, maxlat;
 
-  for (size_t j = 0; j < ny; j++)
+  for (size_t j = 0; j < ny; ++j)
     {
       if (ybounds[0] > ybounds[1])
         {
@@ -373,7 +373,7 @@ gridGenBoundsRLL(int gridID, size_t nx, size_t ny, const std::vector<double> &xb
           minlat = ybounds[2 * j];
         }
 
-      for (size_t i = 0; i < nx; i++)
+      for (size_t i = 0; i < nx; ++i)
         {
           minlon = xbounds[2 * i];
           maxlon = xbounds[2 * i + 1];
@@ -396,7 +396,7 @@ void
 grid_gen_xbounds2D(size_t nx, size_t ny, const std::vector<double> &xbounds, std::vector<double> &xbounds2D)
 {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(nx, ny, xbounds, xbounds2D)
+#pragma omp parallel for default(none) shared(nx, ny, xbounds, xbounds2D) schedule(static)
 #endif
   for (size_t i = 0; i < nx; ++i)
     {
@@ -418,7 +418,7 @@ void
 grid_gen_ybounds2D(size_t nx, size_t ny, const std::vector<double> &ybounds, std::vector<double> &ybounds2D)
 {
 #ifdef _OPENMP
-#pragma omp parallel for default(none) shared(nx, ny, ybounds, ybounds2D)
+#pragma omp parallel for default(none) shared(nx, ny, ybounds, ybounds2D) schedule(static)
 #endif
   for (size_t j = 0; j < ny; ++j)
     {
@@ -838,10 +838,10 @@ static void
 check_units(const char *name, const char *units)
 {
   const auto len = strlen(units);
-  const bool lvalid_units
+  const auto unitsIsValid
       = (len == 1 && *units == 'm') || (len == 2 && memcmp(units, "km", 2) == 0) || (strncmp(units, "meter", 5) == 0);
 
-  if (!lvalid_units)
+  if (!unitsIsValid)
     cdo_warning("Possibly wrong result! %s %s-coordinate units: %s%s%s (expected \"m\" or \"km\"; default \"m\")",
                 len ? "Invalid" : "Missing", name, len ? "\"" : "", units, len ? "\"" : "");
 }
@@ -850,8 +850,8 @@ static void
 center_1D_to_2D(size_t nx, size_t ny, const std::vector<double> &xvals, const std::vector<double> &yvals,
                 std::vector<double> &xvals2D, std::vector<double> &yvals2D, double xscale, double yscale)
 {
-  for (size_t j = 0; j < ny; j++)
-    for (size_t i = 0; i < nx; i++)
+  for (size_t j = 0; j < ny; ++j)
+    for (size_t i = 0; i < nx; ++i)
       {
         xvals2D[j * nx + i] = xscale * xvals[i];
         yvals2D[j * nx + i] = yscale * yvals[j];
@@ -862,8 +862,8 @@ static void
 bounds_1D_to_2D(size_t nx, size_t ny, const std::vector<double> &xbounds, const std::vector<double> &ybounds,
                 std::vector<double> &xbounds2D, std::vector<double> &ybounds2D, double xscale, double yscale)
 {
-  for (size_t j = 0; j < ny; j++)
-    for (size_t i = 0; i < nx; i++)
+  for (size_t j = 0; j < ny; ++j)
+    for (size_t i = 0; i < nx; ++i)
       {
         const auto index = 4 * (j * nx + i);
         xbounds2D[index + 0] = xscale * xbounds[2 * i];
@@ -905,7 +905,10 @@ get_projection(int gridID1)
       char gmapname[CDI_MAX_NAME];
       int length = CDI_MAX_NAME;
       cdiInqKeyString(gridID1, CDI_GLOBAL, CDI_KEY_GRIDMAP_NAME, gmapname, &length);
-      cdo_abort("Projection type >%s< unsupported!", gmapname);
+      if (length)
+        cdo_abort("Projection type >%s< unsupported!", gmapname);
+      else
+        cdo_abort("Projection parameter missing!");
     }
   // clang-format on
 
@@ -925,7 +928,7 @@ apply_projection(Projection projection, std::vector<char> &proj_params, int grid
 }
 
 int
-gridToCurvilinear(int gridID1, int lbounds)
+gridToCurvilinear(int gridID1, int withBounds)
 {
   const auto gridtype = gridInqType(gridID1);
   if (!(gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_PROJECTION))
@@ -950,8 +953,8 @@ gridToCurvilinear(int gridID1, int lbounds)
       // if (projection != Projection::none) gridtype = GRID_LONLAT;
     }
 
-  const bool lprojection = projection == Projection::proj_laea || projection == Projection::proj_lcc
-                           || projection == Projection::proj_sinu || projection == Projection::proj_stere;
+  const auto lprojection = (projection == Projection::proj_laea || projection == Projection::proj_lcc
+                            || projection == Projection::proj_sinu || projection == Projection::proj_stere);
 
   const auto nvertex = (size_t) gridInqNvertex(gridID1);
 
@@ -1012,7 +1015,7 @@ gridToCurvilinear(int gridID1, int lbounds)
   gridDefXvals(gridID2, xvals2D.data());
   gridDefYvals(gridID2, yvals2D.data());
 
-  if (lbounds)
+  if (withBounds)
     {
       std::vector<double> xbounds, ybounds;
 
@@ -1067,8 +1070,7 @@ gridToCurvilinear(int gridID1, int lbounds)
               if (lprojection || projection == Projection::proj_params)
                 {
                   bounds_1D_to_2D(nx, ny, xbounds, ybounds, xbounds2D, ybounds2D, xscale, yscale);
-                  if (projection != Projection::none)
-                    apply_projection(projection, proj_params, gridID1, 4 * gridsize, xbounds2D.data(), ybounds2D.data());
+                  apply_projection(projection, proj_params, gridID1, 4 * gridsize, xbounds2D.data(), ybounds2D.data());
                 }
               else
                 {
@@ -1113,8 +1115,8 @@ gridToUnstructuredSelecton(int gridID1, size_t selectionSize, size_t *selectionI
   gridDefYsize(unstructuredSelectionGridID, selectionSize);
   std::vector<double> xvals(selectionSize), yvals(selectionSize);
 
-  for (size_t i = 0; i < selectionSize; i++) xvals[i] = xvalsUnstructured[selectionIndexList[i]];
-  for (size_t i = 0; i < selectionSize; i++) yvals[i] = yvalsUnstructured[selectionIndexList[i]];
+  for (size_t i = 0; i < selectionSize; ++i) xvals[i] = xvalsUnstructured[selectionIndexList[i]];
+  for (size_t i = 0; i < selectionSize; ++i) yvals[i] = yvalsUnstructured[selectionIndexList[i]];
 
   gridDefXvals(unstructuredSelectionGridID, xvals.data());
   gridDefYvals(unstructuredSelectionGridID, yvals.data());
@@ -1127,11 +1129,11 @@ gridToUnstructuredSelecton(int gridID1, size_t selectionSize, size_t *selectionI
       std::vector<double> xboundsUnstructured(nvertex * unstructuredGridSize), yboundsUnstructured(nvertex * unstructuredGridSize);
       gridInqXbounds(unstructuredGridID, xboundsUnstructured.data());
       gridInqYbounds(unstructuredGridID, yboundsUnstructured.data());
-      for (size_t i = 0; i < selectionSize; i++)
+      for (size_t i = 0; i < selectionSize; ++i)
         {
           const auto offset = selectionIndexList[i] * nvertex;
-          for (size_t k = 0; k < nvertex; k++) xbounds[i * nvertex + k] = xboundsUnstructured[offset + k];
-          for (size_t k = 0; k < nvertex; k++) ybounds[i * nvertex + k] = yboundsUnstructured[offset + k];
+          for (size_t k = 0; k < nvertex; ++k) xbounds[i * nvertex + k] = xboundsUnstructured[offset + k];
+          for (size_t k = 0; k < nvertex; ++k) ybounds[i * nvertex + k] = yboundsUnstructured[offset + k];
         }
       gridDefNvertex(unstructuredSelectionGridID, nvertex);
       gridDefXbounds(unstructuredSelectionGridID, xbounds.data());
@@ -1142,7 +1144,7 @@ gridToUnstructuredSelecton(int gridID1, size_t selectionSize, size_t *selectionI
 }
 
 static void
-gridToUnstructuredRegular(int gridID1, int gridID2, size_t gridsize, int lbounds, bool lproj_rll)
+gridToUnstructuredRegular(int gridID1, int gridID2, size_t gridsize, int withBounds, bool lproj_rll)
 {
   cdiDefKeyString(gridID2, CDI_XAXIS, CDI_KEY_NAME, "lon");
   cdiDefKeyString(gridID2, CDI_YAXIS, CDI_KEY_NAME, "lat");
@@ -1178,7 +1180,7 @@ gridToUnstructuredRegular(int gridID1, int gridID2, size_t gridsize, int lbounds
     gridDefYvals(gridID2, yvals2D.data());
   }
 
-  if (lbounds)
+  if (withBounds)
     {
       const size_t nvertex = (size_t) gridInqNvertex(gridID1);
       std::vector<double> xbounds, ybounds;
@@ -1229,7 +1231,7 @@ gridToUnstructuredRegular(int gridID1, int gridID2, size_t gridsize, int lbounds
 }
 
 static void
-gridToUnstructuredGaussianReduced(int gridID1, int gridID2, size_t gridsize, int lbounds)
+gridToUnstructuredGaussianReduced(int gridID1, int gridID2, size_t gridsize, int withBounds)
 {
   cdiDefKeyString(gridID2, CDI_XAXIS, CDI_KEY_NAME, "lon");
   cdiDefKeyString(gridID2, CDI_YAXIS, CDI_KEY_NAME, "lat");
@@ -1284,7 +1286,7 @@ gridToUnstructuredGaussianReduced(int gridID1, int gridID2, size_t gridsize, int
 
   gridDefXvals(gridID2, xvals.data());
 
-  if (lbounds)
+  if (withBounds)
     {
       const auto nvertex = (size_t) gridInqNvertex(gridID1);
       std::vector<double> ybounds;
@@ -1325,7 +1327,7 @@ gridToUnstructuredGaussianReduced(int gridID1, int gridID2, size_t gridsize, int
 }
 
 static void
-gridToUnstructuredGME(int gridID1, int gridID2, size_t gridsize, int lbounds)
+gridToUnstructuredGME(int gridID1, int gridID2, size_t gridsize, int withBounds)
 {
   constexpr size_t nv = 6;
 
@@ -1335,18 +1337,18 @@ gridToUnstructuredGME(int gridID1, int gridID2, size_t gridsize, int lbounds)
   std::vector<int> imask(gridsize);
   std::vector<double> xvals(gridsize), yvals(gridsize);
   std::vector<double> xbounds, ybounds;
-  if (lbounds) xbounds.resize(nv * gridsize);
-  if (lbounds) ybounds.resize(nv * gridsize);
+  if (withBounds) xbounds.resize(nv * gridsize);
+  if (withBounds) ybounds.resize(nv * gridsize);
 
-  gme_grid(lbounds, gridsize, xvals.data(), yvals.data(), xbounds.data(), ybounds.data(), imask.data(), ni, nd, ni2, ni3);
+  gme_grid(withBounds, gridsize, xvals.data(), yvals.data(), xbounds.data(), ybounds.data(), imask.data(), ni, nd, ni2, ni3);
 
-  for (size_t i = 0; i < gridsize; i++)
+  for (size_t i = 0; i < gridsize; ++i)
     {
       xvals[i] *= RAD2DEG;
       yvals[i] *= RAD2DEG;
 
-      if (lbounds)
-        for (size_t j = 0; j < nv; j++)
+      if (withBounds)
+        for (size_t j = 0; j < nv; ++j)
           {
             xbounds[i * nv + j] *= RAD2DEG;
             ybounds[i * nv + j] *= RAD2DEG;
@@ -1364,8 +1366,8 @@ gridToUnstructuredGME(int gridID1, int gridID2, size_t gridsize, int lbounds)
 
   gridDefNvertex(gridID2, nv);
 
-  if (lbounds) gridDefXbounds(gridID2, xbounds.data());
-  if (lbounds) gridDefYbounds(gridID2, ybounds.data());
+  if (withBounds) gridDefXbounds(gridID2, xbounds.data());
+  if (withBounds) gridDefYbounds(gridID2, ybounds.data());
 
   cdiDefKeyString(gridID2, CDI_XAXIS, CDI_KEY_UNITS, "degrees_east");
   cdiDefKeyString(gridID2, CDI_YAXIS, CDI_KEY_UNITS, "degrees_north");
@@ -1374,13 +1376,13 @@ gridToUnstructuredGME(int gridID1, int gridID2, size_t gridsize, int lbounds)
 }
 
 int
-gridToUnstructured(int gridID1, int lbounds)
+gridToUnstructured(int gridID1, int withBounds)
 {
   auto gridID2 = CDI_UNDEFID;
   auto gridtype = gridInqType(gridID1);
   const auto gridsize = gridInqSize(gridID1);
 
-  bool lproj_rll = false;
+  auto lproj_rll = false;
   if (gridtype == GRID_PROJECTION && gridInqProjType(gridID1) == CDI_PROJ_RLL)
     {
       gridtype = GRID_LONLAT;
@@ -1393,19 +1395,19 @@ gridToUnstructured(int gridID1, int lbounds)
     case GRID_GAUSSIAN:
       {
         gridID2 = gridCreate(GRID_UNSTRUCTURED, gridsize);
-        gridToUnstructuredRegular(gridID1, gridID2, gridsize, lbounds, lproj_rll);
+        gridToUnstructuredRegular(gridID1, gridID2, gridsize, withBounds, lproj_rll);
         break;
       }
     case GRID_GAUSSIAN_REDUCED:
       {
         gridID2 = gridCreate(GRID_UNSTRUCTURED, gridsize);
-        gridToUnstructuredGaussianReduced(gridID1, gridID2, gridsize, lbounds);
+        gridToUnstructuredGaussianReduced(gridID1, gridID2, gridsize, withBounds);
         break;
       }
     case GRID_GME:
       {
         gridID2 = gridCreate(GRID_UNSTRUCTURED, gridsize);
-        gridToUnstructuredGME(gridID1, gridID2, gridsize, lbounds);
+        gridToUnstructuredGME(gridID1, gridID2, gridsize, withBounds);
         break;
       }
     case GRID_CURVILINEAR:
@@ -1432,7 +1434,7 @@ int
 gridCurvilinearToRegular(int gridID1)
 {
   int gridID2 = -1;
-  bool lx = true, ly = true;
+  auto lx = true, ly = true;
 
   const auto gridtype = gridInqType(gridID1);
   const auto gridsize = gridInqSize(gridID1);
@@ -1448,11 +1450,11 @@ gridCurvilinearToRegular(int gridID1)
 
   std::vector<double> xvals(nx), yvals(ny);
 
-  for (size_t i = 0; i < nx; i++) xvals[i] = xvals2D[i];
-  for (size_t j = 0; j < ny; j++) yvals[j] = yvals2D[j * nx];
+  for (size_t i = 0; i < nx; ++i) xvals[i] = xvals2D[i];
+  for (size_t j = 0; j < ny; ++j) yvals[j] = yvals2D[j * nx];
 
-  for (size_t j = 1; j < ny; j++)
-    for (size_t i = 0; i < nx; i++)
+  for (size_t j = 1; j < ny; ++j)
+    for (size_t i = 0; i < nx; ++i)
       {
         if (std::fabs(xvals[i] - xvals2D[j * nx + i]) > 1.e-6)
           {
@@ -1462,8 +1464,8 @@ gridCurvilinearToRegular(int gridID1)
           }
       }
 
-  for (size_t i = 1; i < nx; i++)
-    for (size_t j = 0; j < ny; j++)
+  for (size_t i = 1; i < nx; ++i)
+    for (size_t j = 0; j < ny; ++j)
       {
         if (std::fabs(yvals[j] - yvals2D[j * nx + i]) > 1.e-6)
           {
@@ -1492,10 +1494,10 @@ gridCurvilinearToRegular(int gridID1)
 }
 
 static int
-gridGenWeights(int gridID, double *grid_area, double *grid_wgts)
+compute_gridcell_weights(int gridID, Varray<double> &gridCellArea, Varray<double> &gridCellWeights)
 {
   int status = 0;
-  std::vector<int> grid_mask;
+  std::vector<int> gridMask;
 
   const auto gridtype = gridInqType(gridID);
   const auto gridsize = gridInqSize(gridID);
@@ -1503,50 +1505,50 @@ gridGenWeights(int gridID, double *grid_area, double *grid_wgts)
   if (gridtype == GRID_GME)
     {
       gridID = gridToUnstructured(gridID, 1);
-      grid_mask.resize(gridsize);
-      gridInqMaskGME(gridID, grid_mask.data());
+      gridMask.resize(gridsize);
+      gridInqMaskGME(gridID, gridMask.data());
     }
 
-  double total_area = 0;
+  double total_area = 0.0;
   int nvals = 0;
-  for (size_t i = 0; i < gridsize; i++)
+  for (size_t i = 0; i < gridsize; ++i)
     {
-      if (grid_mask.size())
-        if (grid_mask[i] == 0) continue;
-      total_area += grid_area[i];
+      if (gridMask.size())
+        if (gridMask[i] == 0) continue;
+      total_area += gridCellArea[i];
       nvals++;
     }
 
   if (gridVerbose) cdo_print("Total area = %g", total_area);
 
-  for (size_t i = 0; i < gridsize; i++)
+  for (size_t i = 0; i < gridsize; ++i)
     {
-      if (grid_mask.size())
-        if (grid_mask[i] == 0)
+      if (gridMask.size())
+        if (gridMask[i] == 0)
           {
-            grid_wgts[i] = 0;
+            gridCellWeights[i] = 0.0;
             continue;
           }
 
-      grid_wgts[i] = grid_area[i] / total_area;
+      gridCellWeights[i] = gridCellArea[i] / total_area;
     }
 
   return status;
 }
 
 int
-gridWeights(const int gridID, double *grid_wgts)
+gridcell_weights(const int gridID, Varray<double> &gridCellWeights)
 {
-  int w_status = 1;
-  int a_status = 0;
+  auto weightStatus = 1;
+  auto areaStatus = 0;
 
   const auto gridsize = gridInqSize(gridID);
-  std::vector<double> grid_area(gridsize);
+  std::vector<double> gridCellArea(gridsize);
 
   if (gridHasArea(gridID))
     {
       if (gridVerbose) cdo_print("Using existing grid cell area!");
-      gridInqArea(gridID, grid_area.data());
+      gridInqArea(gridID, gridCellArea.data());
     }
   else
     {
@@ -1554,37 +1556,36 @@ gridWeights(const int gridID, double *grid_wgts)
       if (gridProjIsSupported(gridID) || gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN || gridtype == GRID_GME
           || gridtype == GRID_CURVILINEAR || gridtype == GRID_UNSTRUCTURED)
         {
-          a_status = gridGenArea(gridID, grid_area.data());
-          if (a_status != 0 && (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN))
-            a_status = gridGenAreaReg2Dweights(gridID, grid_area.data());
+          areaStatus = gridGenArea(gridID, gridCellArea.data());
+          if (areaStatus != 0 && (gridtype == GRID_LONLAT || gridtype == GRID_GAUSSIAN))
+            areaStatus = gridGenAreaReg2Dweights(gridID, gridCellArea.data());
         }
       else
         {
-          a_status = 1;
+          areaStatus = 1;
         }
     }
 
-  if (a_status == 0)
+  if (areaStatus == 0)
     {
-      w_status = gridGenWeights(gridID, grid_area.data(), grid_wgts);
+      weightStatus = compute_gridcell_weights(gridID, gridCellArea, gridCellWeights);
     }
   else
     {
-      for (size_t i = 0; i < gridsize; ++i) grid_wgts[i] = 1. / gridsize;
+      for (size_t i = 0; i < gridsize; ++i) gridCellWeights[i] = 1.0 / gridsize;
     }
   /*
-  for ( i = 0; i < gridsize; ++i )
-    printf("weights: %d %d %d %g %g\n", a_status, w_status, i, grid_area[i],
-  grid_wgts[i]);
+  for (i = 0; i < gridsize; ++i)
+    printf("weights: %d %d %d %g %g\n", areaStatus, weightStatus, i, gridCellArea[i], gridCellWeights[i]);
   */
 
-  return w_status;
+  return weightStatus;
 }
 
 bool
 grid_is_distance_generic(int gridID)
 {
-  bool status = false;
+  auto status = false;
 
   if (gridInqType(gridID) == GRID_GENERIC)
     {
@@ -1644,13 +1645,13 @@ generate_full_grid(int gridID, bool withBounds)
 int
 generate_full_point_grid(int gridID)
 {
-  constexpr bool withBounds = false;
+  constexpr auto withBounds = false;
   return generate_full_grid(gridID, withBounds);
 }
 
 int
 generate_full_cell_grid(int gridID)
 {
-  constexpr bool withBounds = true;
+  constexpr auto withBounds = true;
   return generate_full_grid(gridID, withBounds);
 }
